@@ -58,6 +58,7 @@
 #include <ardour/audioengine.h>
 #include <ardour/playlist.h>
 #include <ardour/utils.h>
+#include <ardour/plugin.h>
 #include <ardour/audio_diskstream.h>
 #include <ardour/audiofilesource.h>
 #include <ardour/recent_sessions.h>
@@ -78,6 +79,7 @@ typedef uint64_t microseconds_t;
 #include "new_session_dialog.h"
 #include "about.h"
 #include "splash.h"
+#include "nag.h"
 #include "utils.h"
 #include "gui_thread.h"
 #include "theme_manager.h"
@@ -225,6 +227,8 @@ ARDOUR_UI::ARDOUR_UI (int *argcp, char **argvp[])
 	ARDOUR::Diskstream::DiskOverrun.connect (mem_fun(*this, &ARDOUR_UI::disk_overrun_handler));
 	ARDOUR::Diskstream::DiskUnderrun.connect (mem_fun(*this, &ARDOUR_UI::disk_underrun_handler));
 
+	ARDOUR::Plugin::PresetFileExists.connect (mem_fun(*this, &ARDOUR_UI::preset_file_exists_handler));
+
 	/* handle dialog requests */
 
 	ARDOUR::Session::Dialog.connect (mem_fun(*this, &ARDOUR_UI::session_dialog));
@@ -898,8 +902,14 @@ void
 ARDOUR_UI::update_buffer_load ()
 {
 	char buf[64];
+	uint32_t c, p;
 
 	if (session) {
+		c = session->capture_load ();
+		p = session->playback_load ();
+		
+		push_buffer_stats (c, p);
+
 		snprintf (buf, sizeof (buf), _("Buffers p:%" PRIu32 "%% c:%" PRIu32 "%%"), 
 			  session->playback_load(), session->capture_load());
 		buffer_load_label.set_text (buf);
@@ -1840,11 +1850,24 @@ ARDOUR_UI::snapshot_session ()
 	prompter.add_button (Gtk::Stock::SAVE, Gtk::RESPONSE_ACCEPT);
 	prompter.set_prompt (_("Name of New Snapshot"));
 	prompter.set_initial_text (timebuf);
-	
+
+  again:
 	switch (prompter.run()) {
 	case RESPONSE_ACCEPT:
 		prompter.get_result (snapname);
 		if (snapname.length()){
+			if (snapname.find ('/') != string::npos) {
+				MessageDialog msg (_("To ensure compatibility with various systems\n"
+						     "snapshot names may not contain a '/' character"));
+				msg.run ();
+				goto again;
+			}
+			if (snapname.find ('\\') != string::npos) {
+				MessageDialog msg (_("To ensure compatibility with various systems\n"
+						     "snapshot names may not contain a '\\' character"));
+				msg.run ();
+				goto again;
+			}
 			save_state (snapname);
 		}
 		break;
@@ -2200,7 +2223,7 @@ ARDOUR_UI::get_session_parameters (bool backend_audio_is_running, bool should_be
 	Glib::ustring session_path;
 	Glib::ustring template_name;
 	int response;
-
+	
   begin:
 	response = Gtk::RESPONSE_NONE;
 
@@ -2297,7 +2320,7 @@ ARDOUR_UI::get_session_parameters (bool backend_audio_is_running, bool should_be
 		if (response == Gtk::RESPONSE_OK) {
 
 			session_name = new_session_dialog->session_name();
-
+			
 			if (session_name.empty()) {
 				response = Gtk::RESPONSE_NONE;
 				goto try_again;
@@ -2315,7 +2338,7 @@ ARDOUR_UI::get_session_parameters (bool backend_audio_is_running, bool should_be
 				session_name = Glib::path_get_basename (session_name);
 				
 			} else {
-
+				
 				session_path = new_session_dialog->session_folder();
 			}
 
@@ -2330,10 +2353,26 @@ ARDOUR_UI::get_session_parameters (bool backend_audio_is_running, bool should_be
 			case NewSessionDialog::NewPage: /* nominally the "new" session creator, but could be in use for an old session */
 				
 				should_be_new = true;
-				
+
+				if (session_name.find ('/') != Glib::ustring::npos) {
+					MessageDialog msg (*new_session_dialog, _("To ensure compatibility with various systems\n"
+							 "session names may not contain a '/' character"));
+					msg.run ();
+					response = RESPONSE_NONE;
+					goto try_again;
+				}
+
+				if (session_name.find ('\\') != Glib::ustring::npos) {
+					MessageDialog msg (*new_session_dialog, _("To ensure compatibility with various systems\n"
+							 "session names may not contain a '\\' character"));
+					msg.run ();
+					response = RESPONSE_NONE;
+					goto try_again;
+				}
+
 				//XXX This is needed because session constructor wants a 
 				//non-existant path. hopefully this will be fixed at some point.
-				
+
 				session_path = Glib::build_filename (session_path, session_name);
 
 				if (Glib::file_test (session_path, Glib::FileTest (G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR))) {
@@ -2398,7 +2437,9 @@ ARDOUR_UI::close_session ()
 		return;
 	}
 
-	unload_session (true);
+	if (unload_session (true)) {
+		return;
+	}
 	
 	get_session_parameters (true, false);
 }
@@ -2590,6 +2631,16 @@ ARDOUR_UI::show_about ()
 	about->show_all ();
 }
 
+void
+ARDOUR_UI::launch_chat ()
+{
+#ifdef __APPLE__
+	NagScreen::open_uri("http://webchat.freenode.net/?channels=ardour-osx");
+#else
+	NagScreen::open_uri("http://webchat.freenode.net/?channels=ardour");
+#endif
+}
+
 void
 ARDOUR_UI::hide_about ()
 {
@@ -2853,6 +2904,13 @@ ARDOUR_UI::add_route (Gtk::Window* float_window)
 		return;
 	}
 
+	string template_path = add_route_dialog->track_template();
+
+	if (!template_path.empty()) {
+	  session->new_route_from_template (count, template_path);
+	  return;
+	}
+	
 	uint32_t input_chan = add_route_dialog->channels ();
 	uint32_t output_chan;
 	string name_template = add_route_dialog->name_template ();
@@ -2961,11 +3019,100 @@ ARDOUR_UI::xrun_handler(nframes_t where)
 	}
 }
 
+bool
+ARDOUR_UI::preset_file_exists_handler ()
+{
+	/* if driven from another thread, say "do not overwrite" and show the user nothing.
+	 */
+
+	if (!Gtkmm2ext::UI::instance()->caller_is_ui_thread()) {	\
+		return false;
+	}
+	
+ 	HBox* hbox = new HBox();
+	Image* image = new Image (Stock::DIALOG_QUESTION, ICON_SIZE_DIALOG);
+	Gtk::Dialog dialog (_("Preset Exists"), true, false);
+	Label  message (_("\
+A preset with this name already exists for this plugin.\n\
+\n\
+What you would like to do?\n"));
+	image->set_alignment(ALIGN_CENTER, ALIGN_TOP);
+	hbox->pack_start (*image, PACK_EXPAND_WIDGET, 12);
+	hbox->pack_end (message, PACK_EXPAND_PADDING, 12);
+	dialog.get_vbox()->pack_start(*hbox, PACK_EXPAND_PADDING, 6);
+	dialog.add_button (_("Overwrite the existing preset"), RESPONSE_ACCEPT);
+	dialog.add_button (_("Leave the existing preset alone"), RESPONSE_REJECT);
+	dialog.set_default_response (RESPONSE_ACCEPT);
+	dialog.set_position (WIN_POS_MOUSE);
+	dialog.set_type_hint (Gdk::WINDOW_TYPE_HINT_UTILITY); // need to make it float above the preset name dialog
+
+	message.show();
+	image->show();
+	hbox->show();
+
+	switch (dialog.run ()) {
+	case RESPONSE_ACCEPT:
+		return true;
+	default:
+		return false;
+	}
+}
+
+void
+ARDOUR_UI::push_buffer_stats (uint32_t capture, uint32_t playback)
+{
+	time_t now;
+	time (&now);
+
+	while (disk_buffer_stats.size() > 60) {
+		disk_buffer_stats.pop_front ();
+	}
+
+	disk_buffer_stats.push_back (DiskBufferStat (now, capture, playback));
+}
+
+void
+ARDOUR_UI::write_buffer_stats ()
+{
+	std::ofstream fout;
+	struct tm tm;
+	char buf[64];
+	char* path;
+
+	if ((path = tempnam (0, "ardourBuffering")) == 0) {
+		cerr << X_("cannot find temporary name for ardour buffer stats") << endl;
+		return;
+	}
+
+	fout.open (path);
+
+	if (!fout) {
+		cerr << string_compose (X_("cannot open file %1 for ardour buffer stats"), path) << endl;
+		return;
+	}
+
+	for (list<DiskBufferStat>::iterator i = disk_buffer_stats.begin(); i != disk_buffer_stats.end(); ++i) {
+		localtime_r (&(*i).when, &tm);
+		strftime (buf, sizeof (buf), "%T", &tm);
+		fout << buf << ' ' << (*i).capture << ' ' << (*i).playback << endl;
+	}
+	
+	disk_buffer_stats.clear ();
+
+	fout.close ();
+
+	cerr << "Ardour buffering statistics can be found in: " << path << endl;
+	free (path);
+}
+
 void
 ARDOUR_UI::disk_overrun_handler ()
 {
+
 	ENSURE_GUI_THREAD (mem_fun(*this, &ARDOUR_UI::disk_overrun_handler));
 
+	write_buffer_stats ();
+
 	if (!have_disk_speed_dialog_displayed) {
 		have_disk_speed_dialog_displayed = true;
 		MessageDialog* msg = new MessageDialog (*editor, _("\
@@ -2982,8 +3129,11 @@ quickly enough to keep up with recording.\n"));
 void
 ARDOUR_UI::disk_underrun_handler ()
 {
+
 	ENSURE_GUI_THREAD (mem_fun(*this, &ARDOUR_UI::disk_underrun_handler));
 
+	write_buffer_stats ();
+
 	if (!have_disk_speed_dialog_displayed) {
 		have_disk_speed_dialog_displayed = true;
 		MessageDialog* msg = new MessageDialog (*editor,
@@ -3048,6 +3198,8 @@ what you would like to do.\n"));
 	image->show();
 	hbox->show();
 
+	pop_back_splash ();
+
 	switch (dialog.run ()) {
 	case RESPONSE_ACCEPT:
 		return 1;
