@@ -857,9 +857,9 @@ CrossfadeEditor::build_presets ()
 	fade_in_presets = new Presets;
 	fade_out_presets = new Presets;
 
-	/* FADE OUT */
+	/* FADE IN */
 
-	p = new Preset ("Linear (-6dB)", "crossfade_in_dipped");
+	p = new Preset ("Linear (-6dB)", "crossfade-in-linear");
 	p->push_back (PresetPoint (0, 0));
 	p->push_back (PresetPoint (0.000000, 0.000000));
 	p->push_back (PresetPoint (0.166667, 0.166366));
@@ -870,7 +870,7 @@ CrossfadeEditor::build_presets ()
 	p->push_back (PresetPoint (1.000000, 1.000000));
 	fade_in_presets->push_back (p);
 
-	p = new Preset ("S(1)-curve", "crossfade_in_default");
+	p = new Preset ("S(1)-curve", "crossfade-in-S1");
 	p->push_back (PresetPoint (0, 0));
 	p->push_back (PresetPoint (0.1, 0.01));
 	p->push_back (PresetPoint (0.2, 0.03));
@@ -879,7 +879,7 @@ CrossfadeEditor::build_presets ()
 	p->push_back (PresetPoint (1, 1));
 	fade_in_presets->push_back (p);
 
-	p = new Preset ("S(2)-curve", "crossfade_in_default");
+	p = new Preset ("S(2)-curve", "crossfade-in-S2");
 	p->push_back (PresetPoint (0.0, 0.0));
 	p->push_back (PresetPoint (0.055, 0.222));
 	p->push_back (PresetPoint (0.163, 0.35));
@@ -888,7 +888,7 @@ CrossfadeEditor::build_presets ()
 	p->push_back (PresetPoint (1.0, 1.0));
 	fade_in_presets->push_back (p);
 
-	p = new Preset ("Constant Power (-3dB)", "crossfade_in_constant");
+	p = new Preset ("Constant Power (-3dB)", "crossfade-in-constant-power");
 
 	p->push_back (PresetPoint (0.000000, 0.000000));
 	p->push_back (PresetPoint (0.166667, 0.282192));
@@ -901,20 +901,8 @@ CrossfadeEditor::build_presets ()
 	fade_in_presets->push_back (p);
 
 	if (!Profile->get_sae()) {
-		// p = new Preset ("hiin.xpm");
-		p = new Preset ("Long cut", "crossfade_in_fast-cut");
-		p->push_back (PresetPoint (0, 0));
-		p->push_back (PresetPoint (0.0207373, 0.197222));
-		p->push_back (PresetPoint (0.0645161, 0.525));
-		p->push_back (PresetPoint (0.152074, 0.802778));
-		p->push_back (PresetPoint (0.276498, 0.919444));
-		p->push_back (PresetPoint (0.481567, 0.980556));
-		p->push_back (PresetPoint (0.767281, 1));
-		p->push_back (PresetPoint (1, 1));
-		fade_in_presets->push_back (p);
-		
-		// p = new Preset ("loin.xpm");
-		p = new Preset ("Short cut", "crossfade_in_transition");
+
+	  	p = new Preset ("Short cut", "crossfade-in-short-cut");
 		p->push_back (PresetPoint (0, 0));
 		p->push_back (PresetPoint (0.389401, 0.0333333));
 		p->push_back (PresetPoint (0.629032, 0.0861111));
@@ -924,9 +912,7 @@ CrossfadeEditor::build_presets ()
 		p->push_back (PresetPoint (1, 1));
 		fade_in_presets->push_back (p);
 		
-		
-		// p = new Preset ("regin2.xpm");
-		p = new Preset ("Slow cut", "crossfade_in_slow-cut");
+		p = new Preset ("Slow cut", "crossfade-in-slow-cut");
 		p->push_back (PresetPoint (0, 0));
 		p->push_back (PresetPoint (0.304147, 0.0694444));
 		p->push_back (PresetPoint (0.529954, 0.152778));
@@ -935,12 +921,33 @@ CrossfadeEditor::build_presets ()
 		p->push_back (PresetPoint (0.919355, 0.730556));
 		p->push_back (PresetPoint (1, 1));
 		fade_in_presets->push_back (p);
+		
+		p = new Preset ("Fast cut", "crossfade-in-fast-cut");
+		p->push_back (PresetPoint (0, 0));
+		p->push_back (PresetPoint (0.0737327, 0.308333));
+		p->push_back (PresetPoint (0.246544, 0.658333));
+		p->push_back (PresetPoint (0.470046, 0.886111));
+		p->push_back (PresetPoint (0.652074, 0.972222));
+		p->push_back (PresetPoint (0.771889, 0.988889));
+		p->push_back (PresetPoint (1, 1));
+		fade_in_presets->push_back (p);
+
+		p = new Preset ("Long cut", "crossfade-in-long-cut");
+		p->push_back (PresetPoint (0, 0));
+		p->push_back (PresetPoint (0.0207373, 0.197222));
+		p->push_back (PresetPoint (0.0645161, 0.525));
+		p->push_back (PresetPoint (0.152074, 0.802778));
+		p->push_back (PresetPoint (0.276498, 0.919444));
+		p->push_back (PresetPoint (0.481567, 0.980556));
+		p->push_back (PresetPoint (0.767281, 1));
+		p->push_back (PresetPoint (1, 1));
+		fade_in_presets->push_back (p);
 	}
 	
 	/* FADE OUT */
 
 	// p = new Preset ("regout.xpm");
-	p = new Preset ("Linear (-6dB cut)", "crossfade_out_dipped");
+	p = new Preset ("Linear (-6dB cut)", "crossfade-out-linear");
 	p->push_back (PresetPoint (0, 1));
 	p->push_back (PresetPoint (0.000000, 1.000000));
 	p->push_back (PresetPoint (0.166667, 0.833033));
@@ -951,7 +958,7 @@ CrossfadeEditor::build_presets ()
 	p->push_back (PresetPoint (1.000000, 0.000000));
 	fade_out_presets->push_back (p);
 
-	p = new Preset ("S(1)-Curve", "crossfade_out_default");
+	p = new Preset ("S(1)-Curve", "crossfade-out-S1");
 	p->push_back (PresetPoint (0, 1));
 	p->push_back (PresetPoint (0.1, 0.99));
 	p->push_back (PresetPoint (0.2, 0.97));
@@ -960,7 +967,7 @@ CrossfadeEditor::build_presets ()
 	p->push_back (PresetPoint (1, 0));
 	fade_out_presets->push_back (p);
 
-	p = new Preset ("S(2)-Curve", "crossfade_out_default");
+	p = new Preset ("S(2)-Curve", "crossfade-out-S2");
 	p->push_back (PresetPoint (0.0, 1.0));
 	p->push_back (PresetPoint (0.163, 0.678));
 	p->push_back (PresetPoint (0.055, 0.783));
@@ -970,7 +977,7 @@ CrossfadeEditor::build_presets ()
 	fade_out_presets->push_back (p);
 
 	// p = new Preset ("linout.xpm");
-	p = new Preset ("Constant Power (-3dB cut)", "crossfade_out_constant");
+	p = new Preset ("Constant Power (-3dB cut)", "crossfade-out-constant-power");
 	p->push_back (PresetPoint (0.000000, 1.000000));
 	p->push_back (PresetPoint (0.166667, 0.948859));
 	p->push_back (PresetPoint (0.333333, 0.851507));
@@ -982,7 +989,7 @@ CrossfadeEditor::build_presets ()
 	
 	if (!Profile->get_sae()) {
 		// p = new Preset ("hiout.xpm");
-		p = new Preset ("Slow end/cut", "crossfade_out_fast-cut");
+		p = new Preset ("Short cut", "crossfade-out-short-cut");
 		p->push_back (PresetPoint (0, 1));
 		p->push_back (PresetPoint (0.305556, 1));
 		p->push_back (PresetPoint (0.548611, 0.991736));
@@ -992,8 +999,27 @@ CrossfadeEditor::build_presets ()
 		p->push_back (PresetPoint (1, 0));
 		fade_out_presets->push_back (p);
 		
+		p = new Preset ("Slow cut", "crossfade-out-slow-cut");
+		p->push_back (PresetPoint (0, 1));
+		p->push_back (PresetPoint (0.228111, 0.988889));
+		p->push_back (PresetPoint (0.347926, 0.972222));
+		p->push_back (PresetPoint (0.529954, 0.886111));
+		p->push_back (PresetPoint (0.753456, 0.658333));
+		p->push_back (PresetPoint (0.9262673, 0.308333));
+		p->push_back (PresetPoint (1, 0));
+		fade_out_presets->push_back (p);
+		
+		p = new Preset ("Fast cut", "crossfade-out-fast-cut");
+		p->push_back (PresetPoint (0, 1));
+		p->push_back (PresetPoint (0.080645, 0.730556));
+		p->push_back (PresetPoint (0.277778, 0.289256));
+		p->push_back (PresetPoint (0.470046, 0.152778));
+		p->push_back (PresetPoint (0.695853, 0.0694444));
+		p->push_back (PresetPoint (1, 0));
+		fade_out_presets->push_back (p);
+		
 		// p = new Preset ("loout.xpm");
-		p = new Preset ("Fast start/cut", "crossfade_out_transition");
+		p = new Preset ("Long cut", "crossfade-out-long-cut");
 		p->push_back (PresetPoint (0, 1));
 		p->push_back (PresetPoint (0.023041, 0.697222));
 		p->push_back (PresetPoint (0.0553,   0.483333));
@@ -1003,15 +1029,6 @@ CrossfadeEditor::build_presets ()
 		p->push_back (PresetPoint (1, 0));
 		fade_out_presets->push_back (p);
 		
-		// p = new Preset ("regout2.xpm");
-		p = new Preset ("Slow Fade", "crossfade_out_slow-fade");
-		p->push_back (PresetPoint (0, 1));
-		p->push_back (PresetPoint (0.080645, 0.730556));
-		p->push_back (PresetPoint (0.277778, 0.289256));
-		p->push_back (PresetPoint (0.470046, 0.152778));
-		p->push_back (PresetPoint (0.695853, 0.0694444));
-		p->push_back (PresetPoint (1, 0));
-		fade_out_presets->push_back (p);
 	}
 }
 
