@@ -286,6 +286,7 @@ class Editor : public PublicEditor
 	void clear_playlists (TimeAxisView*);
 
 	TrackViewList* get_valid_views (TimeAxisView*, ARDOUR::RouteGroup* grp = 0);
+	void get_onscreen_tracks (TrackViewList&);
 
 	Width editor_mixer_strip_width;
 	void maybe_add_mixer_strip_width (XMLNode&);
@@ -307,6 +308,10 @@ class Editor : public PublicEditor
 
 	/* playhead/screen stuff */
 	
+	void set_stationary_playhead (bool yn);
+	void toggle_stationary_playhead ();
+	bool stationary_playhead() const { return _stationary_playhead; }
+
 	void set_follow_playhead (bool yn);
 	void toggle_follow_playhead ();
 	bool follow_playhead() const { return _follow_playhead; }
@@ -588,8 +593,6 @@ class Editor : public PublicEditor
 	Gdk::Cursor* which_grabber_cursor ();
 
 	ArdourCanvas::Canvas* track_canvas;
-
-	ArdourCanvas::Text* first_action_message;
 	ArdourCanvas::Text* verbose_canvas_cursor;
 	bool                 verbose_cursor_visible;
 
@@ -777,18 +780,20 @@ class Editor : public PublicEditor
 	Cursor* playhead_cursor;
 	ArdourCanvas::Group* cursor_group;
 
-	void    cursor_to_region_boundary (Cursor*, int32_t dir);
-	void    cursor_to_next_region_boundary (Cursor*);
-	void    cursor_to_previous_region_boundary (Cursor*);
+	nframes64_t get_region_boundary (nframes64_t pos, int32_t dir, bool with_selection, bool only_onscreen);
+
+	void    cursor_to_region_boundary (bool with_selection, int32_t dir);
+	void    cursor_to_next_region_boundary (bool with_selection);
+	void    cursor_to_previous_region_boundary (bool with_selection);
 	void    cursor_to_next_region_point (Cursor*, ARDOUR::RegionPoint);
 	void    cursor_to_previous_region_point (Cursor*, ARDOUR::RegionPoint);
 	void    cursor_to_region_point (Cursor*, ARDOUR::RegionPoint, int32_t dir);
 	void    cursor_to_selection_start (Cursor *);
 	void    cursor_to_selection_end   (Cursor *);
 
-	void    selected_marker_to_region_boundary (int32_t dir);
-	void    selected_marker_to_next_region_boundary ();
-	void    selected_marker_to_previous_region_boundary ();
+	void    selected_marker_to_region_boundary (bool with_selection, int32_t dir);
+	void    selected_marker_to_next_region_boundary (bool with_selection);
+	void    selected_marker_to_previous_region_boundary (bool with_selection);
 	void    selected_marker_to_next_region_point (ARDOUR::RegionPoint);
 	void    selected_marker_to_previous_region_point (ARDOUR::RegionPoint);
 	void    selected_marker_to_region_point (ARDOUR::RegionPoint, int32_t dir);
@@ -858,8 +863,6 @@ class Editor : public PublicEditor
 	void tie_vertical_scrolling ();
 	void scroll_canvas_horizontally ();
 	void scroll_canvas_vertically ();
-	void canvas_horizontally_scrolled ();
-	void canvas_scroll_to (nframes64_t);
 
 	struct VisualChange {
 	    enum Type { 
@@ -1095,7 +1098,7 @@ class Editor : public PublicEditor
 	void adjust_region_scale_amplitude (bool up);
 
 	void do_insert_time ();
-	void insert_time (nframes64_t pos, nframes64_t distance, Editing::InsertTimeOption opt, bool ignore_music_glue, bool markers_too);
+	void insert_time (nframes64_t pos, nframes64_t distance, Editing::InsertTimeOption opt, bool ignore_music_glue, bool markers_too, bool tempo_too);
 
 	void tab_to_transient (bool forward);
 
@@ -1471,6 +1474,7 @@ public:
 	
 	bool _show_measures;
 	bool _show_waveforms;
+	bool _stationary_playhead;
 	bool _follow_playhead;
 	bool _show_waveforms_recording;
 	
@@ -1766,6 +1770,7 @@ public:
 	void redisplay_route_list();
 	bool ignore_route_list_reorder;
 	bool no_route_list_redisplay;
+	bool sync_track_view_list_and_route_list ();
 
 	void build_route_list_menu ();
 	void show_route_list_menu ();
@@ -1919,7 +1924,7 @@ public:
 	bool write_region (string path, boost::shared_ptr<ARDOUR::AudioRegion>);
 	void export_region ();
 	void bounce_region_selection ();
-	void bounce_range_selection (bool replace);
+	void bounce_range_selection (bool replace, bool enable_processing = true);
 	void external_edit_region ();
 
 	int write_audio_selection (TimeSelection&);
