@@ -524,6 +524,7 @@ Editor::embed_sndfiles (vector<Glib::ustring> paths, bool multifile,
 	string linked_path;
 	SoundFileInfo finfo;
 	int ret = 0;
+	Glib::ustring path_to_use;
 
 	track_canvas->get_window()->set_cursor (Gdk::Cursor (Gdk::WATCH));
 	gdk_flush ();
@@ -537,6 +538,8 @@ Editor::embed_sndfiles (vector<Glib::ustring> paths, bool multifile,
 		linked_path = session->sound_dir();
 		linked_path += '/';
 		linked_path += Glib::path_get_basename (path);
+
+		path_to_use = path;
 		
 		if (link (path.c_str(), linked_path.c_str()) == 0) {
 
@@ -547,6 +550,7 @@ Editor::embed_sndfiles (vector<Glib::ustring> paths, bool multifile,
 			*/
 			
 			path = linked_path;
+			path_to_use = Glib::path_get_basename (linked_path);
 
 		} else {
 
@@ -558,6 +562,7 @@ Editor::embed_sndfiles (vector<Glib::ustring> paths, bool multifile,
 				if (stat (linked_path.c_str(), &sb) == 0) {
 					if (sb.st_nlink > 1) { // its a hard link, assume its the one we want
 						path = linked_path;
+						path_to_use = Glib::path_get_basename (linked_path);
 					}
 				}
 			}
@@ -638,7 +643,7 @@ Editor::embed_sndfiles (vector<Glib::ustring> paths, bool multifile,
 				if ((s = session->source_by_path_and_channel (path, n)) == 0) {
 
 					source = boost::dynamic_pointer_cast<AudioFileSource> (SourceFactory::createReadable 
-											       (*session, path,  n,
+											       (*session, path_to_use,  n,
 												(mode == ImportAsTapeTrack ? 
 												 AudioFileSource::Destructive : 
 												 AudioFileSource::Flag (0)),
@@ -678,8 +683,11 @@ Editor::add_sources (vector<Glib::ustring> paths, SourceList& sources, nframes64
 	ustring region_name;
 	uint32_t input_chan = 0;
 	uint32_t output_chan = 0;
+	bool use_timestamp;
+	
+	use_timestamp = (pos == -1);
 
-	if (pos == -1) { // "use timestamp"
+	if (use_timestamp) {
 		if (sources[0]->natural_position() != 0) {
 			pos = sources[0]->natural_position();
 		} else {
@@ -692,10 +700,15 @@ Editor::add_sources (vector<Glib::ustring> paths, SourceList& sources, nframes64
 		/* take all the sources we have and package them up as a region */
 
 		region_name = region_name_from_path (paths.front(), (sources.size() > 1), false);
-		
-		regions.push_back (boost::dynamic_pointer_cast<AudioRegion> 
+		boost::shared_ptr<AudioRegion> ar = boost::dynamic_pointer_cast<AudioRegion> 
 				   (RegionFactory::create (sources, 0, sources[0]->length(), region_name, 0,
-							   Region::Flag (Region::DefaultFlags|Region::WholeFile|Region::External))));
+							   Region::Flag (Region::DefaultFlags|Region::WholeFile|Region::External)));
+							   
+        if (use_timestamp) {
+		    ar->special_set_position(sources[0]->natural_position());
+		}
+		
+		regions.push_back (ar);
 		
 	} else if (target_regions == -1 || target_regions > 1) {
 
@@ -713,11 +726,15 @@ Editor::add_sources (vector<Glib::ustring> paths, SourceList& sources, nframes64
 			boost::shared_ptr<AudioFileSource> afs = boost::dynamic_pointer_cast<AudioFileSource> (*x);
 
 			region_name = region_name_from_path (afs->path(), false, true, sources.size(), n);
-
-			regions.push_back (boost::dynamic_pointer_cast<AudioRegion> 
+			boost::shared_ptr<AudioRegion> ar = boost::dynamic_pointer_cast<AudioRegion> 
 					   (RegionFactory::create (just_one, 0, (*x)->length(), region_name, 0,
-								   Region::Flag (Region::DefaultFlags|Region::WholeFile|Region::External))));
+								   Region::Flag (Region::DefaultFlags|Region::WholeFile|Region::External)));
 
+            if (use_timestamp) {
+    		    ar->special_set_position((*x)->natural_position());
+    		}
+
+			regions.push_back (ar);
 		}
 	}
 
