@@ -338,16 +338,9 @@ Editor::track_canvas_size_allocated ()
 
 	if (session) {
 		TrackViewList::iterator i;
-		double height = 0;
-
 		for (i = track_views.begin(); i != track_views.end(); ++i) {
-			if ((*i)->control_parent) {
-				height += (*i)->effective_height;
-			}
 			(*i)->clip_to_viewport ();
 		}
-		
-		full_canvas_height = height + canvas_timebars_vsize;
 	}
 
 	if (height_changed) {
@@ -392,7 +385,6 @@ Editor::controls_layout_size_request (Requisition* req)
 		TimeAxisView *tv = (*i)[route_display_columns.tv];
 		if (tv != 0) {
 			pos += tv->effective_height;
-			tv->clip_to_viewport ();
 		}
 	}
 
@@ -832,28 +824,24 @@ Editor::tie_vertical_scrolling ()
 void
 Editor::scroll_canvas_horizontally ()
 {
-	nframes64_t time_origin = (nframes64_t) floor (horizontal_adjustment.get_value() * frames_per_unit);
-
-	if (time_origin != leftmost_frame) {
-		canvas_scroll_to (time_origin);
-	}
-
 	/* horizontal scrolling only */
-	double x1, x2, y1, y2, x_delta;
+	double x1, y1, x2, y2, x_delta;
+	_master_group->get_bounds (x1, y1, x2, y2);
 
-	_master_group->get_bounds(x1, y1, x2, y2);
-	x_delta = x1 + horizontal_adjustment.get_value();
+	x_delta = - (x1 +  horizontal_adjustment.get_value());
 
-	_master_group->move (-x_delta, 0);
-	timebar_group->move (-x_delta, 0);
-	time_line_group->move (-x_delta, 0);
-	cursor_group->move (-x_delta, 0);
+	_master_group->move (x_delta, 0);
+	timebar_group->move (x_delta, 0);
+	time_line_group->move (x_delta, 0);
+	cursor_group->move (x_delta, 0);
+
+	leftmost_frame = (nframes64_t) floor (horizontal_adjustment.get_value() * frames_per_unit);
 
 	update_fixed_rulers ();
 	redisplay_tempo (true);
 
 #ifndef GTKOSX
-	if (!autoscroll_active) {
+	if (!autoscroll_active && !_stationary_playhead) {
 		/* force rulers and canvas to move in lock step */
 		while (gtk_events_pending ()) {
 			gtk_main_iteration ();
@@ -882,23 +870,6 @@ Editor::scroll_canvas_vertically ()
 	track_canvas->update_now ();
 }
 
-void 
-Editor::canvas_horizontally_scrolled ()
-{
-	nframes64_t time_origin = (nframes64_t) floor (horizontal_adjustment.get_value() * frames_per_unit);
-
-	if (time_origin != leftmost_frame) {
-		canvas_scroll_to (time_origin);
-	}
-	redisplay_tempo (true);
-}
-
-void
-Editor::canvas_scroll_to (nframes64_t time_origin)
-{
-	leftmost_frame = time_origin;
-}
-
 void
 Editor::color_handler()
 {
