@@ -222,6 +222,17 @@ Editor::update_current_screen ()
 			goto almost_done;
 		}
 
+#undef DEBUG_CURRENT_SCREEN
+#if DEBUG_CURRENT_SCREEN
+
+		cerr << "@ " << frame << " last " << last_update_frame << " follow " << _follow_playhead 
+		     << " ret " << session->requested_return_frame()
+		     << " left " << leftmost_frame
+		     << " right " << leftmost_frame + current_page_frames()
+		     << " speed " << session->transport_speed ()
+		     << endl;
+#endif
+
 		/* only update if the playhead is on screen or we are following it */
 
 		if (_follow_playhead && session->requested_return_frame() < 0) {
@@ -231,10 +242,12 @@ Editor::update_current_screen ()
 			if (frame != last_update_frame) {
 
 
-#undef CONTINUOUS_SCROLL
-#ifndef  CONTINUOUS_SCROLL
+		if ( !_stationary_playhead ) {
 				if (frame < leftmost_frame || frame > leftmost_frame + current_page_frames()) {
-					
+
+#ifdef DEBUG_CURRENT_SCREEN
+					cerr << "\trecenter...\n";
+#endif 					
 					if (session->transport_speed() < 0) {
 						if (frame > (current_page_frames()/2)) {
 							center_screen (frame-(current_page_frames()/2));
@@ -248,7 +261,7 @@ Editor::update_current_screen ()
 
 				playhead_cursor->set_position (frame);
 
-#else  // CONTINUOUS_SCROLL
+		} else {
 				
 				/* don't do continuous scroll till the new position is in the rightmost quarter of the 
 				   editor canvas
@@ -269,7 +282,7 @@ Editor::update_current_screen ()
 				
 				playhead_cursor->set_position (frame);
 
-#endif // CONTINUOUS_SCROLL
+				}
 
 			}
 
@@ -382,11 +395,15 @@ Editor::session_going_away ()
 		current_bbt_points = 0;
 	}
 
-	/* mixer strip will be deleted all by itself 
-	   when its route is deleted.
-	*/
+	/* get rid of any existing editor mixer strip */
 
-	current_mixer_strip = 0;
+	if (current_mixer_strip) {
+		if (current_mixer_strip->get_parent() != 0) {
+			global_hpacker.remove (*current_mixer_strip);
+		}
+		delete current_mixer_strip;
+		current_mixer_strip = 0;
+	}
 
 	WindowTitle title(Glib::get_application_name());
 	title += _("Editor");
