@@ -251,6 +251,16 @@ Editor::set_selected_control_point_from_click (Selection::Operation op, bool no_
 	return select_all_within (x1, x2, y1, y2, selection->tracks, op);
 }
 
+void
+Editor::get_onscreen_tracks (TrackViewList& tvl)
+{
+	for (TrackViewList::iterator i = track_views.begin(); i != track_views.end(); ++i) {
+		if ((*i)->y_position < canvas_height) {
+			tvl.push_back (*i);
+		}
+	}
+}
+
 void
 Editor::get_relevant_audio_tracks (set<AudioTimeAxisView*>& relevant_tracks)
 {
