@@ -276,23 +276,8 @@ EngineControl::EngineControl ()
 	++row;
 #endif
 
-	find_jack_servers (server_strings);
-
-	if (server_strings.empty()) {
-		fatal << _("No JACK server found anywhere on this system. Please install JACK and restart") << endmsg;
-		/*NOTREACHED*/
-	}
-	
-	set_popdown_strings (serverpath_combo, server_strings);
-	serverpath_combo.set_active_text (server_strings.front());
-
-	if (server_strings.size() > 1) {
-		label = manage (new Label (_("Server:")));
-		options_packer.attach (*label, 0, 1, row, row + 1, FILL|EXPAND, (AttachOptions) 0);
-		label->set_alignment (0.0, 0.5);
-		options_packer.attach (serverpath_combo, 1, 2, row, row + 1, FILL|EXPAND, (AttachOptions) 0);
-		++row;
-	}
+	/* defer server stuff till later */
+	server_row = row++;
 
 	/* device settings */
 
@@ -353,6 +338,27 @@ EngineControl::~EngineControl ()
 
 }
 
+void
+EngineControl::discover_servers ()
+{
+	find_jack_servers (server_strings);
+
+	if (server_strings.empty()) {
+		fatal << _("No JACK server found anywhere on this system. Please install JACK and restart") << endmsg;
+		/*NOTREACHED*/
+	}
+	
+	set_popdown_strings (serverpath_combo, server_strings);
+	serverpath_combo.set_active_text (server_strings.front());
+
+	if (server_strings.size() > 1) {
+		Gtk::Label* label = manage (new Label (_("Server:")));
+		options_packer.attach (*label, 0, 1, server_row, server_row + 1, FILL|EXPAND, (AttachOptions) 0);
+		label->set_alignment (0.0, 0.5);
+		options_packer.attach (serverpath_combo, 1, 2, server_row, server_row + 1, FILL|EXPAND, (AttachOptions) 0);
+	}
+}
+
 void
 EngineControl::build_command_line (vector<string>& cmd)
 {
@@ -1243,24 +1249,35 @@ EngineControl::set_state (const XMLNode& root)
 		} else if (child->name() == "periodsize") {
 			period_size_combo.set_active_text(strval);
 		} else if (child->name() == "serverpath") {
-			/* do not allow us to use a server path that doesn't
-			   exist on this system. this handles cases where
-			   the user has an RC file listing a serverpath
-			   from some other machine.
+
+			/* only attempt to set this if we have bothered to look
+			   up server names already. otherwise this is all
+			   redundant (actually, all of this dialog/widget 
+			   is redundant in that case ...)
 			*/
-			vector<string>::iterator x;
-			for (x = server_strings.begin(); x != server_strings.end(); ++x) {
-				if (*x == strval) {
-					break;
+		       
+
+			if (!server_strings.empty()) {
+				/* do not allow us to use a server path that doesn't
+				   exist on this system. this handles cases where
+				   the user has an RC file listing a serverpath
+				   from some other machine.
+				*/
+				vector<string>::iterator x;
+				for (x = server_strings.begin(); x != server_strings.end(); ++x) {
+					if (*x == strval) {
+						break;
+					}
+				}
+				if (x != server_strings.end()) {
+					serverpath_combo.set_active_text (strval);
+				} else {
+					warning << string_compose (_("configuration files contain a JACK server path that doesn't exist (%1)"),
+								   strval)
+						<< endmsg;
 				}
 			}
-			if (x != server_strings.end()) {
-				serverpath_combo.set_active_text (strval);
-			} else {
-				warning << string_compose (_("configuration files contain a JACK server path that doesn't exist (%1)"),
-							     strval)
-					<< endmsg;
-			}
+
 		} else if (child->name() == "driver") {
 			driver_combo.set_active_text(strval);
 		} else if (child->name() == "interface") {
