@@ -46,10 +46,10 @@ using namespace Gtkmm2ext;
 LocationEditRow::LocationEditRow(Session * sess, Location * loc, int32_t num)
 	: location(0), session(0),
 	  item_table (1, 7, false),
-	  start_set_button (_("Set")),
+	  start_set_button (_("Use PH")),
 	  start_go_button (_("Go")),
 	  start_clock (X_("locationstart"), true, X_("LocationEditRowClock"), true),
-	  end_set_button (_("Set")),
+	  end_set_button (_("Use PH")),
 	  end_go_button (_("Go")),
 	  end_clock (X_("locationend"), true, X_("LocationEditRowClock"), true),
 	  length_clock (X_("locationlength"), true, X_("LocationEditRowClock"), true, true),
@@ -82,7 +82,9 @@ LocationEditRow::LocationEditRow(Session * sess, Location * loc, int32_t num)
 	composer_label.set_name ("LocationEditNumberLabel");
 	composer_entry.set_name ("LocationEditNameEntry");
 
-
+	ARDOUR_UI::instance()->tooltips().set_tip(start_set_button, _("Set value to Playhead"));
+	ARDOUR_UI::instance()->tooltips().set_tip(end_set_button, _("Set value to Playhead"));
+ 
 	isrc_label.set_text ("ISRC: ");
 	isrc_label.set_size_request (30, -1);
 	performer_label.set_text ("Performer: ");
@@ -131,6 +133,7 @@ LocationEditRow::LocationEditRow(Session * sess, Location * loc, int32_t num)
 	start_set_button.signal_clicked().connect(bind (mem_fun (*this, &LocationEditRow::set_button_pressed), LocStart));
 	start_go_button.signal_clicked().connect(bind (mem_fun (*this, &LocationEditRow::go_button_pressed), LocStart));
  	start_clock.ValueChanged.connect (bind (mem_fun (*this, &LocationEditRow::clock_changed), LocStart));
+ 	start_clock.ChangeAborted.connect (bind (mem_fun (*this, &LocationEditRow::change_aborted), LocStart));
 
 	
 	end_hbox.pack_start (end_go_button, false, false);
@@ -142,9 +145,11 @@ LocationEditRow::LocationEditRow(Session * sess, Location * loc, int32_t num)
 	end_set_button.signal_clicked().connect(bind (mem_fun (*this, &LocationEditRow::set_button_pressed), LocEnd));
 	end_go_button.signal_clicked().connect(bind (mem_fun (*this, &LocationEditRow::go_button_pressed), LocEnd));
 	end_clock.ValueChanged.connect (bind (mem_fun (*this, &LocationEditRow::clock_changed), LocEnd));
+ 	end_clock.ChangeAborted.connect (bind (mem_fun (*this, &LocationEditRow::change_aborted), LocEnd));
 	
 //	item_table.attach (length_clock, 3, 4, 0, 1, 0, 0, 4, 0);
 	length_clock.ValueChanged.connect (bind ( mem_fun(*this, &LocationEditRow::clock_changed), LocLength));
+ 	length_clock.ChangeAborted.connect (bind (mem_fun (*this, &LocationEditRow::change_aborted), LocLength));
 
 //	item_table.attach (cd_check_button, 4, 5, 0, 1, 0, Gtk::FILL, 4, 0);
 //	item_table.attach (hide_check_button, 5, 6, 0, 1, 0, Gtk::FILL, 4, 0);
@@ -414,6 +419,14 @@ LocationEditRow::clock_changed (LocationPart part)
 
 }
 
+void
+LocationEditRow::change_aborted (LocationPart part)
+{
+	if (i_am_the_modifier || !location) return;
+	
+	set_location(location);
+}
+
 void
 LocationEditRow::cd_toggled ()
 {
@@ -600,6 +613,12 @@ LocationEditRow::flags_changed (ARDOUR::Location *loc, void *src)
 	i_am_the_modifier--;
 }
 
+void
+LocationEditRow::focus_name() {
+	name_entry.grab_focus();
+}
+
+
 LocationUI::LocationUI ()
 	: ArdourDialog ("locations dialog"),
 	  add_location_button (_("Add New Location")),
@@ -628,6 +647,8 @@ LocationUI::LocationUI ()
 	location_rows_scroller.set_name ("LocationLocRowsScroller");
 	location_rows_scroller.set_policy (Gtk::POLICY_NEVER, Gtk::POLICY_AUTOMATIC);
 	location_rows_scroller.set_size_request (-1, 130);
+	
+	newest_location = 0;
 
 	loc_frame_box.set_spacing (5);
 	loc_frame_box.set_border_width (5);
@@ -789,6 +810,10 @@ LocationUI::map_locations (Locations::LocationList& locations)
 			erow->remove_requested.connect (mem_fun(*this, &LocationUI::location_remove_requested));
  			erow->redraw_ranges.connect (mem_fun(*this, &LocationUI::location_redraw_ranges));
 			loc_children.push_back(Box_Helpers::Element(*erow, PACK_SHRINK, 1, PACK_START));
+			if (location == newest_location) {
+				newest_location = 0;
+				erow->focus_name();
+			}
 		}
 		else if (location->is_auto_punch()) {
 			punch_edit_row.set_session (session);
@@ -820,6 +845,9 @@ LocationUI::add_new_location()
 		nframes_t where = session->audible_frame();
 		session->locations()->next_available_name(markername,"mark");
 		Location *location = new Location (where, where, markername, Location::IsMark);
+		if (Config->get_name_new_markers()) {
+			newest_location = location;			
+		}
 		session->begin_reversible_command (_("add marker"));
 		XMLNode &before = session->locations()->get_state();
 		session->locations()->add (location, true);
