@@ -102,6 +102,14 @@ MixerStrip::MixerStrip (Mixer_UI& mx, Session& sess, bool in_mixer)
 
 {
 	init ();
+
+	if (!_mixer_owned) {
+		/* the editor mixer strip: don't destroy it every time
+		   the underlying route goes away.
+		*/
+
+		self_destruct = false;
+	}
 }
 
 MixerStrip::MixerStrip (Mixer_UI& mx, Session& sess, boost::shared_ptr<Route> rt, bool in_mixer)
@@ -134,6 +142,7 @@ MixerStrip::init ()
 	group_menu = 0;
 	_marked_for_display = false;
 	route_ops_menu = 0;
+	rename_menu_item = 0;
 	ignore_comment_edit = false;
 	ignore_toggle = false;
 	ignore_speed_adjustment = false;
@@ -1046,7 +1055,9 @@ MixerStrip::build_route_ops_menu ()
 
 	MenuList& items = route_ops_menu->items();
 
+	items.push_back (MenuElem (_("Save As Template"), mem_fun(*this, &RouteUI::save_as_template)));
 	items.push_back (MenuElem (_("Rename"), mem_fun(*this, &RouteUI::route_rename)));
+	rename_menu_item = &items.back();
 	items.push_back (SeparatorElem());
 	items.push_back (CheckMenuElem (_("Active"), mem_fun (*this, &RouteUI::toggle_route_active)));
 	route_active_menu_item = dynamic_cast<CheckMenuItem *> (&items.back());
@@ -1074,11 +1085,8 @@ MixerStrip::name_button_button_press (GdkEventButton* ev)
 {
 	if (ev->button == 1 || ev->button == 3) {
 		list_route_operations ();
-
-		Menu_Helpers::MenuList& items = route_ops_menu->items();
 		/* do not allow rename if the track is record-enabled */
-		static_cast<MenuItem*> (&items.front())->set_sensitive (!_route->record_enabled());
-
+		rename_menu_item->set_sensitive (!_route->record_enabled());
 		route_ops_menu->popup (1, ev->time);
 	}
 	return FALSE;
@@ -1177,16 +1185,16 @@ MixerStrip::width_clicked ()
 void
 MixerStrip::hide_clicked ()
 {
-    // LAME fix to reset the button status for when it is redisplayed (part 1)
-    hide_button.set_sensitive(false);
-    
+	// LAME fix to reset the button status for when it is redisplayed (part 1)
+	hide_button.set_sensitive(false);
+	
 	if (_embedded) {
-		 Hiding(); /* EMIT_SIGNAL */
+		Hiding(); /* EMIT_SIGNAL */
 	} else {
 		_mixer.hide_strip (this);
 	}
 	
-    // (part 2)
+	// (part 2)
 	hide_button.set_sensitive(true);
 }
 
