@@ -75,6 +75,8 @@ class Mixer_UI : public Gtk::Window
 	void hide_strip (MixerStrip *);
 
 	void ensure_float (Gtk::Window&);
+	void toggle_auto_rebinding ();
+	void set_auto_rebinding(bool);
 
 	RouteRedirectSelection& selection() { return _selection; }
 	
@@ -129,6 +131,9 @@ class Mixer_UI : public Gtk::Window
 	void unselect_all_audiobus_strips ();
 	void select_all_audiobus_strips ();
 
+	void auto_rebind_midi_controls ();
+	bool auto_rebinding;
+
 	void strip_select_op (bool audiotrack, bool select);
 	void select_strip_op (MixerStrip*, bool select);
 
@@ -147,6 +152,9 @@ class Mixer_UI : public Gtk::Window
 	void redisplay_track_list ();
 	bool no_track_list_redisplay;
 	bool track_display_button_press (GdkEventButton*);
+#ifdef GTKOSX
+	void queue_draw_all_strips ();
+#endif
 	
 	void track_list_change (const Gtk::TreeModel::Path&,const Gtk::TreeModel::iterator&);
 	void track_list_delete (const Gtk::TreeModel::Path&);
@@ -237,9 +245,9 @@ class Mixer_UI : public Gtk::Window
 
 	Width _strip_width;
 
-	void sync_order_keys ();
-	bool ignore_route_reorder;
-	bool ignore_sync;
+	void sync_order_keys (const char *src);
+	bool strip_redisplay_does_not_reset_order_keys;
+	bool strip_redisplay_does_not_sync_order_keys;
 
 	static const int32_t default_width = 478;
 	static const int32_t default_height = 765;
