@@ -122,7 +122,7 @@ PluginUIWindow::PluginUIWindow (Gtk::Window* win, boost::shared_ptr<PluginInsert
 	add_events (Gdk::KEY_PRESS_MASK|Gdk::KEY_RELEASE_MASK|Gdk::BUTTON_PRESS_MASK|Gdk::BUTTON_RELEASE_MASK);
 
 	signal_delete_event().connect (bind (sigc::ptr_fun (just_hide_it), reinterpret_cast<Window*> (this)), false);
-	insert->GoingAway.connect (mem_fun(*this, &PluginUIWindow::plugin_going_away));
+	death_connection = insert->GoingAway.connect (mem_fun(*this, &PluginUIWindow::plugin_going_away));
 
 	gint h = _pluginui->get_preferred_height ();
 	gint w = _pluginui->get_preferred_width ();
@@ -141,6 +141,7 @@ PluginUIWindow::PluginUIWindow (Gtk::Window* win, boost::shared_ptr<PluginInsert
 
 PluginUIWindow::~PluginUIWindow ()
 {
+	delete _pluginui;
 }
 
 void
@@ -315,24 +316,27 @@ void
 PluginUIWindow::plugin_going_away ()
 {
 	ENSURE_GUI_THREAD(mem_fun(*this, &PluginUIWindow::plugin_going_away));
-	
+
 	if (_pluginui) {
 		_pluginui->stop_updating(0);
 	}
+	
+	death_connection.disconnect ();
 	delete_when_idle (this);
 }
 
 PlugUIBase::PlugUIBase (boost::shared_ptr<PluginInsert> pi)
 	: insert (pi),
 	  plugin (insert->plugin()),
-	  save_button(_("Add")),
+	  save_button(_("Save")),
 	  bypass_button (_("Bypass"))
 {
         //preset_combo.set_use_arrows_always(true);
-	set_popdown_strings (preset_combo, plugin->get_presets());
 	preset_combo.set_size_request (100, -1);
-	preset_combo.set_active_text ("");
+	update_presets ();
+
 	preset_combo.signal_changed().connect(mem_fun(*this, &PlugUIBase::setting_selected));
+	no_load_preset = false;
 
 	save_button.set_name ("PluginSaveButton");
 	save_button.signal_clicked().connect(mem_fun(*this, &PlugUIBase::save_plugin_setting));
@@ -354,19 +358,38 @@ PlugUIBase::PlugUIBase (boost::shared_ptr<PluginInsert> pi)
 	
 	focus_button.add (*focus_out_image);
 
-	ARDOUR_UI::instance()->set_tip (&focus_button, _("Click to focus all keyboard events on this plugin window"), "");
+	ARDOUR_UI::instance()->set_tip (&focus_button, _("Click to allow the plugin to receive keyboard events that Ardour would normally use as a shortcut"), "");
 	ARDOUR_UI::instance()->set_tip (&bypass_button, _("Click to enable/disable this plugin"), "");
+
+	insert->GoingAway.connect (mem_fun (*this, &PlugUIBase::plugin_going_away));
+}
+
+PlugUIBase::~PlugUIBase ()
+{
+}
+
+void
+PlugUIBase::plugin_going_away ()
+{
+	/* drop references to the plugin/insert */
+	insert.reset ();
+	plugin.reset ();
 }
 
 void
 PlugUIBase::redirect_active_changed (Redirect* r, void* src)
 {
 	ENSURE_GUI_THREAD(bind (mem_fun(*this, &PlugUIBase::redirect_active_changed), r, src));
+	bypass_button.set_active (!r->active());
 }
 
 void
 PlugUIBase::setting_selected()
 {
+	if (no_load_preset) {
+		return;
+	}
+	
 	if (preset_combo.get_active_text().length() > 0) {
 		if (!plugin->load_preset(preset_combo.get_active_text())) {
 			warning << string_compose(_("Plugin preset %1 not found"), preset_combo.get_active_text()) << endmsg;
@@ -384,6 +407,7 @@ PlugUIBase::save_plugin_setting ()
 	prompter.set_type_hint (Gdk::WINDOW_TYPE_HINT_UTILITY);
 
 	prompter.show_all();
+	prompter.present ();
 
 	switch (prompter.run ()) {
 	case Gtk::RESPONSE_ACCEPT:
@@ -393,9 +417,16 @@ PlugUIBase::save_plugin_setting ()
 		prompter.get_result(name);
 
 		if (name.length()) {
-			if(plugin->save_preset(name)){
+			if (plugin->save_preset(name)) {
+
+				/* a rather inefficient way to add the newly saved preset
+				   to the list.
+				*/
+
 				set_popdown_strings (preset_combo, plugin->get_presets());
+				no_load_preset = true;
 				preset_combo.set_active_text (name);
+				no_load_preset = false;
 			}
 		}
 		break;
@@ -420,13 +451,13 @@ PlugUIBase::focus_toggled (GdkEventButton* ev)
 		focus_button.remove ();
 		focus_button.add (*focus_out_image);
 		focus_out_image->show ();
-		ARDOUR_UI::instance()->set_tip (&focus_button, _("Click to focus all keyboard events on this plugin window"), "");
+		ARDOUR_UI::instance()->set_tip (&focus_button, _("Click to allow the plugin to receive keyboard events that Ardour would normally use as a shortcut"), "");
 	} else {
 		Keyboard::the_keyboard().magic_widget_grab_focus();
 		focus_button.remove ();
 		focus_button.add (*focus_in_image);
 		focus_in_image->show ();
-		ARDOUR_UI::instance()->set_tip (&focus_button, _("Click to remove keyboard focus from this plugin window"), "");
+		ARDOUR_UI::instance()->set_tip (&focus_button, _("Click to allow normal use of Ardour keyboard shortcuts"), "");
 	}
 
 	return true;
@@ -435,5 +466,16 @@ PlugUIBase::focus_toggled (GdkEventButton* ev)
 void
 PlugUIBase::update_presets ()
 {
+	vector<string> presets = plugin->get_presets();
 	set_popdown_strings (preset_combo, plugin->get_presets());
+
+	string current_preset = plugin->current_preset();
+
+	if (!current_preset.empty()) {
+		for (vector<string>::iterator p = presets.begin(); p != presets.end(); ++p) {
+			if (*p == current_preset) {
+				preset_combo.set_active_text (current_preset);
+			}
+		}
+	}
 }
