@@ -78,6 +78,7 @@ using namespace Glib;
 using namespace Gtkmm2ext;
 
 RedirectBox* RedirectBox::_current_redirect_box = 0;
+RefPtr<Action> RedirectBox::cut_action;
 RefPtr<Action> RedirectBox::paste_action;
 bool RedirectBox::get_colors = true;
 Gdk::Color* RedirectBox::active_redirect_color;
@@ -157,6 +158,7 @@ RedirectBox::set_route (boost::shared_ptr<Route> r)
 
 	connections.push_back (_route->redirects_changed.connect (mem_fun(*this, &RedirectBox::redisplay_redirects)));
 	connections.push_back (_route->GoingAway.connect (mem_fun (*this, &RedirectBox::route_going_away)));
+	connections.push_back (_route->name_changed.connect (mem_fun(*this, &RedirectBox::route_name_changed)));
 
 	redisplay_redirects (0);
 }
@@ -254,6 +256,8 @@ RedirectBox::show_redirect_menu (gint arg)
 		plugin_menu_item->set_submenu (_plugin_selector.plugin_menu());
 	}
 
+	cut_action->set_sensitive (can_cut_redirects ());
+	
 	paste_action->set_sensitive (!_rr_selection.redirects.empty());
 
 	redirect_menu->popup (1, arg);
@@ -342,7 +346,11 @@ RedirectBox::redirect_button_release_event (GdkEventButton *ev)
 		show_redirect_menu(ev->time);
 		ret = true;
 
-	} else if (redirect && Keyboard::is_button2_event (ev) && (Keyboard::no_modifier_keys_pressed (ev) && ((ev->state & Gdk::BUTTON2_MASK) == Gdk::BUTTON2_MASK))) {
+	} else if (redirect && Keyboard::is_button2_event (ev)
+#ifndef GTKOSX
+		   && (Keyboard::no_modifier_keys_pressed (ev) && ((ev->state & Gdk::BUTTON2_MASK) == Gdk::BUTTON2_MASK))
+#endif 
+		) {
 		
 		/* button2-click with no modifiers */
 
@@ -762,6 +770,23 @@ RedirectBox::rename_redirects ()
 	}
 }
 
+bool
+RedirectBox::can_cut_redirects ()
+{
+	vector<boost::shared_ptr<Redirect> > sel;
+	get_selected_redirects (sel);
+	
+	/* cut_redirects () does not cut inserts or sends */
+	for (vector<boost::shared_ptr<Redirect> >::const_iterator i = sel.begin (); i != sel.end (); ++i) {
+
+		if (boost::dynamic_pointer_cast<PluginInsert>(*i) != 0) {
+			return true;
+		}
+	}
+
+	return false;
+}
+
 void
 RedirectBox::cut_redirects ()
 {
@@ -1128,10 +1153,7 @@ RedirectBox::edit_redirect (boost::shared_ptr<Redirect> redirect)
 				plugin_ui->set_title (title.get_string());
 				
 				plugin_insert->set_gui (plugin_ui);
-				
-				// change window title when route name is changed
-				_route->name_changed.connect (bind (mem_fun(*this, &RedirectBox::route_name_changed), plugin_ui, boost::weak_ptr<PluginInsert> (plugin_insert)));
-				
+
 			} else {
 				plugin_ui = reinterpret_cast<PluginUIWindow *> (plugin_insert->get_gui());
 				plugin_ui->set_parent (win);
@@ -1206,8 +1228,8 @@ RedirectBox::register_actions ()
 	ActionManager::register_action (popup_act_grp, X_("clear"), _("Clear"),  sigc::ptr_fun (RedirectBox::rb_clear));
 
 	/* standard editing stuff */
-	act = ActionManager::register_action (popup_act_grp, X_("cut"), _("Cut"),  sigc::ptr_fun (RedirectBox::rb_cut));
-	ActionManager::plugin_selection_sensitive_actions.push_back(act);
+	cut_action = ActionManager::register_action (popup_act_grp, X_("cut"), _("Cut"),  sigc::ptr_fun (RedirectBox::rb_cut));
+	ActionManager::plugin_selection_sensitive_actions.push_back (cut_action);
 	act = ActionManager::register_action (popup_act_grp, X_("copy"), _("Copy"),  sigc::ptr_fun (RedirectBox::rb_copy));
 	ActionManager::plugin_selection_sensitive_actions.push_back(act);
 
@@ -1391,16 +1413,39 @@ RedirectBox::rb_edit ()
 }
 
 void
-RedirectBox::route_name_changed (void* src, PluginUIWindow* plugin_ui, boost::weak_ptr<PluginInsert> wpi)
+RedirectBox::route_name_changed (void* src)
 {
-	ENSURE_GUI_THREAD(bind (mem_fun (*this, &RedirectBox::route_name_changed), src, plugin_ui, wpi));
-	boost::shared_ptr<PluginInsert> pi (wpi.lock());
-	
+	boost::shared_ptr<Redirect> redirect;
+	boost::shared_ptr<Insert> insert;
+	Gtk::TreeModel::Children children = model->children();
 
-	if (pi) {
-		WindowTitle title(Glib::get_application_name());
-		title += generate_redirect_title (pi);
-		plugin_ui->set_title (title.get_string());
+	for (Gtk::TreeModel::Children::iterator iter = children.begin(); iter != children.end(); ++iter) {
+  		Gtk::TreeModel::Row row = *iter;
+
+  		redirect= row[columns.redirect];
+		
+		void* gui = redirect->get_gui();
+
+		if (!gui) {
+			continue;
+		}
+
+		/* rename editor windows for sends and plugins */
+
+		WindowTitle title (Glib::get_application_name());
+		
+		if ((insert = boost::dynamic_pointer_cast<Insert> (redirect)) == 0) {
+			boost::shared_ptr<Send> send = boost::dynamic_pointer_cast<Send> (redirect);
+			title += send->name();
+			static_cast<Window*>(gui)->set_title (title.get_string());
+		} else {
+			boost::shared_ptr<PluginInsert> plugin_insert;
+			
+			if ((plugin_insert = boost::dynamic_pointer_cast<PluginInsert> (insert)) != 0) {
+				title += generate_redirect_title (plugin_insert);
+			}
+			static_cast<Window*>(gui)->set_title (title.get_string());
+		}
 	}
 }
 
