@@ -49,11 +49,11 @@ bool TimeAxisViewItem::have_name_font = false;
 const double TimeAxisViewItem::NAME_X_OFFSET = 15.0;
 const double TimeAxisViewItem::GRAB_HANDLE_LENGTH = 6 ;
 
+int TimeAxisViewItem::NAME_HEIGHT;
 double TimeAxisViewItem::NAME_Y_OFFSET;
 double TimeAxisViewItem::NAME_HIGHLIGHT_SIZE;
 double TimeAxisViewItem::NAME_HIGHLIGHT_THRESH;
 
-
 //---------------------------------------------------------------------------------------//
 // Constructor / Desctructor
 
@@ -71,14 +71,14 @@ double TimeAxisViewItem::NAME_HIGHLIGHT_THRESH;
 TimeAxisViewItem::TimeAxisViewItem(const string & it_name, ArdourCanvas::Group& parent, TimeAxisView& tv, double spu, Gdk::Color& base_color, 
 				   nframes_t start, nframes_t duration, bool recording,
 				   Visibility vis)
-	: trackview (tv), _recregion(recording)
+	: trackview (tv), _height(1.0), _recregion(recording)
 {
 	if (!have_name_font) {
 
 		/* first constructed item sets up font info */
 
 		NAME_FONT = get_font_for_style (N_("TimeAxisViewItemName"));
-		
+
 		Gtk::Window win;
 		Gtk::Label foo;
 		win.add (foo);
@@ -90,7 +90,8 @@ TimeAxisViewItem::TimeAxisViewItem(const string & it_name, ArdourCanvas::Group&
 		layout->set_font_description (*NAME_FONT);
 		Gtkmm2ext::get_ink_pixel_size (layout, width, height);
 
-		NAME_Y_OFFSET = height + 6;
+		NAME_HEIGHT = height;
+		NAME_Y_OFFSET = (height / 2) + 8;
 		NAME_HIGHLIGHT_SIZE = height + 6;
 		NAME_HIGHLIGHT_THRESH = NAME_HIGHLIGHT_SIZE * 2;
 
@@ -105,6 +106,7 @@ TimeAxisViewItem::TimeAxisViewItem(const string & it_name, ArdourCanvas::Group&
 
 TimeAxisViewItem::TimeAxisViewItem (const TimeAxisViewItem& other)
 	: trackview (other.trackview)
+	, _height (other._height)
 {
 
 	Gdk::Color c;
@@ -122,13 +124,10 @@ TimeAxisViewItem::TimeAxisViewItem (const TimeAxisViewItem& other)
 	init (other.item_name, other.samples_per_unit, c, other.frame_position, other.item_duration, other.visibility);
 }
 
-
 void
 TimeAxisViewItem::init (const string& it_name, double spu, Gdk::Color& base_color, nframes_t start, nframes_t duration, Visibility vis)
 {
 	item_name = it_name ;
-	name_text_width = ::pixel_width (it_name, *NAME_FONT);
-	last_name_text_width = 0;
 	samples_per_unit = spu ;
 	should_show_selection = true;
 	frame_position = start ;
@@ -141,6 +140,8 @@ TimeAxisViewItem::init (const string& it_name, double spu, Gdk::Color& base_colo
 	show_vestigial = true;
 	visibility = vis;
 	_sensitive = true;
+	name_pixbuf_width = 0;
+	last_item_width = 0;
 
 	if (duration == 0) {
 		warning << "Time Axis Item Duration == 0" << endl ;
@@ -226,19 +227,12 @@ TimeAxisViewItem::init (const string& it_name, double spu, Gdk::Color& base_colo
 	}
 
 	if (visibility & ShowNameText) {
-		name_text = new ArdourCanvas::Text (*group);
-		name_text->property_x() = (double) TimeAxisViewItem::NAME_X_OFFSET;
-		/* trackview.current_height() is the bottom of the trackview. subtract 1 to get back to the bottom of the highlight,
-		   then NAME_Y_OFFSET to position the text in the vertical center of the highlight
-		*/
-		name_text->property_y() = (double) trackview.current_height() - 1.0 - TimeAxisViewItem::NAME_Y_OFFSET;
-		name_text->property_font_desc() = *NAME_FONT;
-		name_text->property_anchor() = Gtk::ANCHOR_NW;
-
-		name_text->set_data ("timeaxisviewitem", this);
-		
+		name_pixbuf = new ArdourCanvas::Pixbuf(*group);
+		name_pixbuf->property_x() = NAME_X_OFFSET;
+		name_pixbuf->property_y() = trackview.current_height() - 1.0 - NAME_Y_OFFSET;
+	
 	} else {
-		name_text = 0;
+		name_pixbuf = 0;
 	}
 
 	set_color (base_color) ;
@@ -487,7 +481,6 @@ TimeAxisViewItem::set_item_name(std::string new_name, void* src)
 	if (new_name != item_name) {
 		std::string temp_name = item_name ;
 		item_name = new_name ;
-		name_text_width = ::pixel_width (new_name, *NAME_FONT);
 		NameChanged (item_name, temp_name, src) ; /* EMIT_SIGNAL */
 	}
 }
@@ -555,11 +548,13 @@ TimeAxisViewItem::get_time_axis_view()
 void
 TimeAxisViewItem::set_name_text(const ustring& new_name)
 {
-	if (name_text) {
-		name_text->property_text() = new_name;
-		name_text_width = pixel_width (new_name, *NAME_FONT);
-		name_text_size_cache.clear ();
+	if (!name_pixbuf) {
+		return;
 	}
+
+	last_item_width = trackview.editor.frame_to_pixel(item_duration);
+	name_pixbuf_width = pixel_width (new_name, *NAME_FONT) + 2;
+	name_pixbuf->property_pixbuf() = pixbuf_from_ustring(new_name, NAME_FONT, name_pixbuf_width, NAME_HEIGHT);
 }
 
 /**
@@ -570,17 +565,13 @@ TimeAxisViewItem::set_name_text(const ustring& new_name)
 void
 TimeAxisViewItem::set_height (double height)
 {
+	_height = height;
+
 	if (name_highlight) {
 		if (height < NAME_HIGHLIGHT_THRESH) {
 			name_highlight->hide();
-			if (name_text) {
-				name_text->hide();
-			}
 		} else {
-			name_highlight->show();
-			if (name_text) {
-				name_text->show();
-			}
+			name_highlight->show();	
 		}
 
 		if (height > NAME_HIGHLIGHT_SIZE) {
@@ -593,12 +584,12 @@ TimeAxisViewItem::set_height (double height)
 		}
 	}
 
-	if (name_text) {
-		name_text->property_y() = height+1 - NAME_Y_OFFSET;
+	if (name_pixbuf) {
 		if (height < NAME_HIGHLIGHT_THRESH) {
-			name_text->property_fill_color_rgba() =  fill_color;
+			name_pixbuf->hide();
 		} else {
-			name_text->property_fill_color_rgba() = label_color;
+			name_pixbuf->property_y() = height+1 - NAME_Y_OFFSET;
+			name_pixbuf->show();
 		}
 	}
 
@@ -649,10 +640,10 @@ TimeAxisViewItem::get_name_highlight()
 /**
  * 
  */
-ArdourCanvas::Text*
-TimeAxisViewItem::get_name_text()
+ArdourCanvas::Pixbuf*
+TimeAxisViewItem::get_name_pixbuf()
 {
-	return (name_text) ;
+	return (name_pixbuf) ;
 }
 
 /**
@@ -756,20 +747,6 @@ void
 TimeAxisViewItem::set_colors()
 {
 	set_frame_color() ;
-	if (name_text) {
-		double height = NAME_HIGHLIGHT_THRESH;
-
-		if (frame) {
-			height = frame->property_y2();
-		}
-
-		if (height < NAME_HIGHLIGHT_THRESH) {
-			name_text->property_fill_color_rgba() =  fill_color;
-		}
-		else {
-			name_text->property_fill_color_rgba() = label_color;
-		}
-	}
 
 	if (name_highlight) {
 		name_highlight->property_fill_color_rgba() = fill_color;
@@ -845,9 +822,10 @@ TimeAxisViewItem::reset_width_dependent_items (double pixel_width)
 
 		if (name_highlight) {
 			name_highlight->hide();
-			if (name_text) {
-				name_text->hide();
-			}
+		}
+
+		if (name_pixbuf) {
+			name_pixbuf->hide();
 		}
 
 		if (frame) {
@@ -864,19 +842,10 @@ TimeAxisViewItem::reset_width_dependent_items (double pixel_width)
 
 		if (name_highlight) {
 
-			double height = name_highlight->property_y2 ();
-
-			if (height < NAME_HIGHLIGHT_THRESH) {
+			if (_height < NAME_HIGHLIGHT_THRESH) {
 				name_highlight->hide();
-				if (name_text) {
-					name_text->hide();
-				}
 			} else {
 				name_highlight->show();
-				if (name_text && !get_item_name().empty()) {
-					name_text->show();
-					reset_name_width (pixel_width);
-				}
 			}
 
 			if (visibility & FullWidthNameHighlight) {
@@ -887,6 +856,14 @@ TimeAxisViewItem::reset_width_dependent_items (double pixel_width)
 
 		}
 
+		if (name_pixbuf) {
+			if (_height < NAME_HIGHLIGHT_THRESH) {
+				name_pixbuf->hide();
+			} else {
+				reset_name_width (pixel_width);
+			}
+		}
+
 		if (frame) {
 			frame->show();
 			frame->property_x2() = pixel_width;
@@ -907,92 +884,42 @@ TimeAxisViewItem::reset_width_dependent_items (double pixel_width)
 }
 
 void
-TimeAxisViewItem::reset_name_width (double pixel_width)
+TimeAxisViewItem::reset_name_width (double pix_width)
 {
-	if (name_text == 0) {
+	uint32_t it_width;
+	int pb_width;
+	bool pixbuf_holds_full_name;
+
+	if (!name_pixbuf) {
 		return;
 	}
 
-	int limit = (int) floor (pixel_width - NAME_X_OFFSET);
-	bool shrinking = (last_name_text_width > pixel_width);
-	int actual_width;
-	ustring ustr;
-	ustring::size_type n;
+	it_width = trackview.editor.frame_to_pixel(item_duration);
+	pb_width = name_pixbuf_width;
 
-	if ((last_name_text_width &&                                       // we did this once
-	     shrinking &&                                                  // we're getting smaller
-	     (name_text_width <= limit) &&                                 // fits the new size
-	     (name_text_width <= last_name_text_width - NAME_X_OFFSET))) { // fit into the old size too
-		last_name_text_width = pixel_width;
+	pixbuf_holds_full_name = last_item_width > pb_width + NAME_X_OFFSET;
+	last_item_width = it_width;
+
+	if (pixbuf_holds_full_name && (it_width >= pb_width + NAME_X_OFFSET)) {
+		/*
+		  we've previously had the full name length showing 
+		  and its still showing.
+		*/
 		return;
 	}
-
-	/* now check the cache of existing truncations */
-
-	Gtk::Label foo;
-	Glib::RefPtr<Pango::Layout> layout = foo.create_pango_layout ("");
-
-	for (n = item_name.length(); n > 0; --n) {
-		
-		map<ustring::size_type,int>::iterator i;
-
-		if ((i = name_text_size_cache.find (n)) != name_text_size_cache.end()) {
-
-			/* we know the length of this substring already */
-			
-			if ((actual_width = (*i).second) < limit) {
-
-				/* it fits, use it */
-				
-				ustr = item_name.substr (0, n);
-				break;
-			}
-						
-		} else {
-			
-			/* we don't know the length of this substring already, so compute
-			   it and put it into the cache.
-			 */
-
-			layout->set_text (item_name.substr (0, n));
-			
-			int width, height;
-			Gtkmm2ext::get_ink_pixel_size (layout, width, height);
-			
-			name_text_size_cache[n] = width;
-
-			if ((actual_width = width) < limit) {
-				ustr = item_name.substr (0, n);
-				break;
-			}
-		}
-	}
-
-	if (n == 0) {
-		name_text->property_text() = "";
-		last_name_text_width = pixel_width;
-		return;
-	} 
-
-	/* don't use name for event handling if it leaves no room
-	   for trimming to work.
-	*/
 	
-	if (pixel_width - actual_width < (NAME_X_OFFSET * 2.0)) {
-		if (name_connected) {
-			name_connected = false;
-		}
+	if (pb_width > it_width - NAME_X_OFFSET) {
+		pb_width = it_width - NAME_X_OFFSET;
+	}
+	
+	if (pb_width <= 0 || it_width <= NAME_X_OFFSET) {
+		name_pixbuf->hide();
+		return;
 	} else {
-		if (!name_connected) {
-			name_connected = true;
-		}
+		name_pixbuf->show();
 	}
-	
-	name_text->property_text() = ustr;
-	name_text_width = actual_width;
-	name_text->show();
-	last_name_text_width = pixel_width;
 
+	name_pixbuf->property_pixbuf() = pixbuf_from_ustring(item_name, NAME_FONT, pb_width, NAME_HEIGHT);
 }
 
 
