@@ -23,7 +23,7 @@
 #include <jack/jack.h>
 #include <string>
 
-#include <libgnomecanvasmm/text.h>
+#include <libgnomecanvasmm/pixbuf.h>
 
 #include "selectable.h"
 #include "simplerect.h"
@@ -200,7 +200,7 @@ class TimeAxisViewItem : public Selectable
      * @param new_name the new name text to display
      */
     void set_name_text(const Glib::ustring& new_name) ;
-    
+
     /**
      * Set the height of this item
      *
@@ -231,7 +231,7 @@ class TimeAxisViewItem : public Selectable
     /**
      * 
      */
-    ArdourCanvas::Text* get_name_text();
+    ArdourCanvas::Pixbuf* get_name_pixbuf();
 
 
     /**
@@ -273,6 +273,7 @@ class TimeAxisViewItem : public Selectable
     /* these are not constant, but vary with the pixel size
        of the font used to display the item name.
     */
+    static int NAME_HEIGHT ;
     static double NAME_Y_OFFSET ;
     static double NAME_HIGHLIGHT_SIZE ;
     static double NAME_HIGHLIGHT_THRESH ;
@@ -434,7 +435,7 @@ class TimeAxisViewItem : public Selectable
      */
 
     bool show_vestigial;
-	uint32_t fill_opacity;
+    uint32_t fill_opacity;
     uint32_t fill_color ;
     uint32_t frame_color_r ;
     uint32_t frame_color_g ;
@@ -450,22 +451,20 @@ class TimeAxisViewItem : public Selectable
     uint32_t lock_handle_color_r ;
     uint32_t lock_handle_color_g ;
     uint32_t lock_handle_color_b ;
-    
+    uint32_t last_item_width;
+    int name_pixbuf_width;
+
     ArdourCanvas::Group*      group;
     ArdourCanvas::SimpleRect* vestigial_frame;
     ArdourCanvas::SimpleRect* frame;
-    ArdourCanvas::Text*       name_text;
+    ArdourCanvas::Pixbuf*     name_pixbuf;
     ArdourCanvas::SimpleRect* name_highlight;
     ArdourCanvas::SimpleRect* frame_handle_start;
     ArdourCanvas::SimpleRect* frame_handle_end;
 
-    int name_text_width;
-    double last_name_text_width;
-
-    std::map<Glib::ustring::size_type,int> name_text_size_cache;
-    
+    double  _height;
     Visibility visibility;
-	bool _recregion;
+    bool _recregion;
 
 
 }; /* class TimeAxisViewItem */
