@@ -79,6 +79,8 @@ class Route : public IO
 	std::string comment() { return _comment; }
 	void set_comment (std::string str, void *src);
 
+	virtual int set_name (string str, void *src);
+
 	long order_key (const char* name) const;
 	void set_order_key (const char* name, long n);
 
@@ -90,13 +92,13 @@ class Route : public IO
 
 
 	virtual int  roll (nframes_t nframes, nframes_t start_frame, nframes_t end_frame, 
-			   nframes_t offset, int declick, bool can_record, bool rec_monitors_input);
+			   int declick, bool can_record, bool rec_monitors_input);
 
 	virtual int  no_roll (nframes_t nframes, nframes_t start_frame, nframes_t end_frame, 
-			      nframes_t offset, bool state_changing, bool can_record, bool rec_monitors_input);
+			      bool state_changing, bool can_record, bool rec_monitors_input);
 
 	virtual int  silent_roll (nframes_t nframes, nframes_t start_frame, nframes_t end_frame, 
-				  nframes_t offset, bool can_record, bool rec_monitors_input);
+				  bool can_record, bool rec_monitors_input);
 	virtual void toggle_monitor_input ();
 	virtual bool can_record() { return false; }
 	virtual void set_record_enable (bool yn, void *src) {}
@@ -206,6 +208,8 @@ class Route : public IO
 	int set_state(const XMLNode& node);
 	virtual XMLNode& get_template();
 
+	int save_as_template (const std::string& path, const std::string& name);
+
 	sigc::signal<void,void*> SelectedChanged;
 
 	int set_control_outs (const vector<std::string>& ports);
@@ -283,7 +287,7 @@ class Route : public IO
 	gain_t                    desired_solo_gain;
 	gain_t                    desired_mute_gain;
 
-	nframes_t            check_initial_delay (nframes_t, nframes_t&, nframes_t&);
+	nframes_t            check_initial_delay (nframes_t, nframes_t&);
 
 	nframes_t           _initial_delay;
 	nframes_t           _roll_delay;
@@ -301,11 +305,11 @@ class Route : public IO
 	ToggleControllable _mute_control;
 	
 	void passthru (nframes_t start_frame, nframes_t end_frame, 
-		       nframes_t nframes, nframes_t offset, int declick, bool meter_inputs);
+		       nframes_t nframes, int declick, bool meter_inputs);
 
 	void process_output_buffers (vector<Sample*>& bufs, uint32_t nbufs,
 				     nframes_t start_frame, nframes_t end_frame,
-				     nframes_t nframes, nframes_t offset, bool with_redirects, int declick,
+				     nframes_t nframes, bool with_redirects, int declick,
 				     bool meter);
 
   protected:
@@ -313,7 +317,7 @@ class Route : public IO
 
 	virtual XMLNode& state(bool);
 
-	void silence (nframes_t nframes, nframes_t offset);
+	void silence (nframes_t nframes);
 	sigc::connection input_signal_connection;
 
 	uint32_t redirect_max_outs;
