@@ -267,8 +267,17 @@ class Session : public PBD::StatefulDestructible
 	static string suffixed_search_path (std::string suffix, bool data);
 	static string control_protocol_path ();
 	static string template_path ();
+	static string route_template_path ();
 	static string template_dir ();
-	static void get_template_list (list<string>&);
+	static string route_template_dir ();
+	static void get_template_list (std::list<std::string>&);
+
+	struct RouteTemplateInfo {
+	  std::string name;
+	  std::string path;
+	};
+
+	static void get_route_templates (std::vector<RouteTemplateInfo>&);
 	
 	static string change_audio_path_by_name (string oldpath, string oldname, string newname, bool destructive);
 	string audio_path_from_name (string, uint32_t nchans, uint32_t chan, bool destructive);
@@ -438,7 +447,6 @@ class Session : public PBD::StatefulDestructible
 	void remove_pending_capture_state ();
 
 	static int rename_template (string old_name, string new_name);
-
 	static int delete_template (string name);
 	
 	sigc::signal<void,string> StateSaved;
@@ -495,6 +503,13 @@ class Session : public PBD::StatefulDestructible
 
 	std::list<boost::shared_ptr<AudioTrack> > new_audio_track (int input_channels, int output_channels, TrackMode mode = Normal, uint32_t how_many = 1);
 	RouteList new_audio_route (int input_channels, int output_channels, uint32_t how_many);
+	RouteList new_route_from_template (uint32_t how_many, const std::string& template_path);
+
+	/* this is a hack put in to support work on video tracks by Robin Gareus. Nobody 
+	   should assume that this works yet (February 2009)
+	*/
+
+ 	boost::shared_ptr<Route> new_video_track (string name);
 
 	void   remove_route (boost::shared_ptr<Route>);
 
@@ -696,8 +711,7 @@ class Session : public PBD::StatefulDestructible
 
 	/* flattening stuff */
 
-	boost::shared_ptr<Region> write_one_audio_track (AudioTrack&, nframes_t start, nframes_t end, bool overwrite, vector<boost::shared_ptr<AudioSource> >&,
-							 InterThreadInfo& wot);
+	boost::shared_ptr<Region> write_one_audio_track (AudioTrack&, nframes_t start, nframes_t end, bool overwrite, vector<boost::shared_ptr<AudioSource> >&, InterThreadInfo& wot, bool enable_processing = true);
 	int freeze (InterThreadInfo&);
 
 	/* session-wide solo/mute/rec-enable */
@@ -1051,7 +1065,11 @@ class Session : public PBD::StatefulDestructible
 	void process_with_events    (nframes_t);
 	void process_audition       (nframes_t);
 	int  process_export         (nframes_t, ARDOUR::AudioExportSpecification*);
-	
+
+	void block_processing() { g_atomic_int_set (&processing_prohibited, 1); }
+	void unblock_processing() { g_atomic_int_set (&processing_prohibited, 0); }
+	bool processing_blocked() const { return g_atomic_int_get (&processing_prohibited); }
+
 	/* slave tracking */
 
 	static const int delta_accumulator_size = 25;
@@ -1071,16 +1089,16 @@ class Session : public PBD::StatefulDestructible
 	nframes_t slave_wait_end;
 
 	void reset_slave_state ();
-	bool follow_slave (nframes_t, nframes_t);
-	void set_slave_source (SlaveSource);
+	bool follow_slave (nframes_t);
+	void set_slave_source (SlaveSource, bool stop_transport = true);
 
 	bool _exporting;
 	int  prepare_to_export (ARDOUR::AudioExportSpecification&);
 
 	void prepare_diskstreams ();
 	void commit_diskstreams (nframes_t, bool& session_requires_butler);
-	int  process_routes (nframes_t, nframes_t);
-	int  silent_process_routes (nframes_t, nframes_t);
+	int  process_routes (nframes_t);
+	int  silent_process_routes (nframes_t);
 
 	bool get_rec_monitors_input () {
 		if (actively_recording()) {
@@ -1114,7 +1132,7 @@ class Session : public PBD::StatefulDestructible
 		return false;
 	}
 
-	bool maybe_sync_start (nframes_t&, nframes_t&);
+	bool maybe_sync_start (nframes_t&);
 
 	void check_declick_out ();
 
@@ -1361,7 +1379,8 @@ class Session : public PBD::StatefulDestructible
 	
 	void reset_record_status ();
 	
-	int no_roll (nframes_t nframes, nframes_t offset);
+	int fail_roll (nframes_t nframes);
+	int no_roll (nframes_t nframes);
 	
 	bool non_realtime_work_pending() const { return static_cast<bool>(post_transport_work); }
 	bool process_can_proceed() const { return !(post_transport_work & ProcessCannotProceedMask); }
@@ -1698,7 +1717,7 @@ class Session : public PBD::StatefulDestructible
 	Click *get_click();
 	void   setup_click_sounds (int which);
 	void   clear_clicks ();
-	void   click (nframes_t start, nframes_t nframes, nframes_t offset);
+	void   click (nframes_t start, nframes_t nframes);
 
 	vector<Route*> master_outs;
 	
@@ -1761,6 +1780,8 @@ class Session : public PBD::StatefulDestructible
 	/* used in ::audible_frame() */
 
 	mutable bool have_looped;
+
+	static void get_templates_from (const std::string& path, std::list<std::string> &template_names);
 };
 
 } // namespace ARDOUR
