@@ -37,6 +37,7 @@
 #include <ardour/playlist_factory.h>
 #include <ardour/panner.h>
 #include <ardour/utils.h>
+#include <ardour/mix.h>
 
 #include "i18n.h"
 
@@ -47,23 +48,7 @@ using namespace PBD;
 AudioTrack::AudioTrack (Session& sess, string name, Route::Flag flag, TrackMode mode)
 	: Track (sess, name, flag, mode)
 {
-	AudioDiskstream::Flag dflags = AudioDiskstream::Flag (0);
-
-	if (_flags & Hidden) {
-		dflags = AudioDiskstream::Flag (dflags | AudioDiskstream::Hidden);
-	} else {
-		dflags = AudioDiskstream::Flag (dflags | AudioDiskstream::Recordable);
-	}
-
-	if (mode == Destructive) {
-		dflags = AudioDiskstream::Flag (dflags | AudioDiskstream::Destructive);
-	}
-
-	boost::shared_ptr<AudioDiskstream> ds (new AudioDiskstream (_session, name, dflags));
-	
-	_session.add_diskstream (ds);
-
-	set_diskstream (boost::dynamic_pointer_cast<AudioDiskstream> (ds), this);
+	use_new_diskstream ();
 }
 
 AudioTrack::AudioTrack (Session& sess, const XMLNode& node)
@@ -76,6 +61,28 @@ AudioTrack::~AudioTrack ()
 {
 }
 
+void
+AudioTrack::use_new_diskstream ()
+{
+	AudioDiskstream::Flag dflags = AudioDiskstream::Flag (0);
+
+	if (_flags & Hidden) {
+		dflags = AudioDiskstream::Flag (dflags | AudioDiskstream::Hidden);
+	} else {
+		dflags = AudioDiskstream::Flag (dflags | AudioDiskstream::Recordable);
+	}
+
+	if (_mode == Destructive) {
+		dflags = AudioDiskstream::Flag (dflags | AudioDiskstream::Destructive);
+	}
+
+	boost::shared_ptr<AudioDiskstream> ds (new AudioDiskstream (_session, name(), dflags));
+	
+	_session.add_diskstream (ds);
+
+	set_diskstream (boost::dynamic_pointer_cast<AudioDiskstream> (ds), this);
+}
+
 int
 AudioTrack::set_mode (TrackMode m)
 {
@@ -269,8 +276,19 @@ AudioTrack::_set_state (const XMLNode& node, bool call_base)
 	} else {
 		
 		PBD::ID id (prop->value());
-		
-		if (use_diskstream (id)) {
+		PBD::ID zero ("0");
+
+		/* this wierd hack is used when creating tracks from a template. there isn't
+		   a particularly good time to interpose between setting the first part of
+		   the track state (notably Route::set_state() and the track mode), and the
+		   second part (diskstream stuff). So, we have a special ID for the diskstream
+		   that means "you should create a new diskstream here, not look for
+		   an old one.
+		*/
+
+		if (id == zero) {
+			use_new_diskstream ();
+		} else if (use_diskstream (id)) {
 			return -1;
 		}
 	}
@@ -292,7 +310,11 @@ AudioTrack::_set_state (const XMLNode& node, bool call_base)
 
 	pending_state = const_cast<XMLNode*> (&node);
 
-	_session.StateReady.connect (mem_fun (*this, &AudioTrack::set_state_part_two));
+	if (_session.state_of_the_state() & Session::Loading) {
+		_session.StateReady.connect (mem_fun (*this, &AudioTrack::set_state_part_two));
+	} else {
+		set_state_part_two ();
+	}
 
 	return 0;
 }
@@ -353,8 +375,11 @@ AudioTrack::set_state_part_two ()
 	XMLProperty* prop;
 	LocaleGuard lg (X_("POSIX"));
 
-	/* This is called after all session state has been restored but before
-	   have been made ports and connections are established.
+	/* During session loading: this is called after all session state has been restored but before
+	   ports have been created and connections are established.
+
+	   During creation from templates: this is called after ports have been created, and connections
+	   are established.
 	*/
 
 	if (pending_state == 0) {
@@ -438,14 +463,15 @@ AudioTrack::n_process_buffers ()
 }
 
 void
-AudioTrack::passthru_silence (nframes_t start_frame, nframes_t end_frame, nframes_t nframes, nframes_t offset, int declick, bool meter)
+AudioTrack::passthru_silence (nframes_t start_frame, nframes_t end_frame, nframes_t nframes, int declick, bool meter)
 {
 	uint32_t nbufs = n_process_buffers ();
-	process_output_buffers (_session.get_silent_buffers (nbufs), nbufs, start_frame, end_frame, nframes, offset, true, declick, meter);
+
+	process_output_buffers (_session.get_silent_buffers (nbufs), nbufs, start_frame, end_frame, nframes, true, declick, meter);
 }
 
 int 
-AudioTrack::no_roll (nframes_t nframes, nframes_t start_frame, nframes_t end_frame, nframes_t offset, 
+AudioTrack::no_roll (nframes_t nframes, nframes_t start_frame, nframes_t end_frame, 
 		     bool session_state_changing, bool can_record, bool rec_monitors_input)
 {
 	if (n_outputs() == 0) {
@@ -453,7 +479,7 @@ AudioTrack::no_roll (nframes_t nframes, nframes_t start_frame, nframes_t end_fra
 	}
 
 	if (!_active) {
-		silence (nframes, offset);
+		silence (nframes);
 		return 0;
 	}
 
@@ -461,7 +487,7 @@ AudioTrack::no_roll (nframes_t nframes, nframes_t start_frame, nframes_t end_fra
 
 		/* XXX is this safe to do against transport state changes? */
 
-		passthru_silence (start_frame, end_frame, nframes, offset, 0, false);
+		passthru_silence (start_frame, end_frame, nframes, 0, false);
 		return 0;
 	}
 
@@ -510,12 +536,12 @@ AudioTrack::no_roll (nframes_t nframes, nframes_t start_frame, nframes_t end_fra
 		*/
 		
 		if (_have_internal_generator) {
-			passthru_silence (start_frame, end_frame, nframes, offset, 0, true);
+			passthru_silence (start_frame, end_frame, nframes, 0, true);
 		} else {
 			if (_meter_point == MeterInput) {
-				just_meter_input (start_frame, end_frame, nframes, offset);
+				just_meter_input (start_frame, end_frame, nframes);
 			}
-			passthru_silence (start_frame, end_frame, nframes, offset, 0, false);
+			passthru_silence (start_frame, end_frame, nframes, 0, false);
 		}
 
 	} else {
@@ -523,14 +549,14 @@ AudioTrack::no_roll (nframes_t nframes, nframes_t start_frame, nframes_t end_fra
 		/* we're sending signal, but we may still want to meter the input. 
 		 */
 
-		passthru (start_frame, end_frame, nframes, offset, 0, (_meter_point == MeterInput));
+		passthru (start_frame, end_frame, nframes, 0, (_meter_point == MeterInput));
 	}
 
 	return 0;
 }
 
 int
-AudioTrack::roll (nframes_t nframes, nframes_t start_frame, nframes_t end_frame, nframes_t offset, int declick,
+AudioTrack::roll (nframes_t nframes, nframes_t start_frame, nframes_t end_frame, int declick,
 		  bool can_record, bool rec_monitors_input)
 {
 	int dret;
@@ -538,7 +564,7 @@ AudioTrack::roll (nframes_t nframes, nframes_t start_frame, nframes_t end_frame,
 	Sample* tmpb;
 	nframes_t transport_frame;
 	boost::shared_ptr<AudioDiskstream> diskstream = audio_diskstream();
-	
+
 	{
 		Glib::RWLock::ReaderLock lm (redirect_lock, Glib::TRY_LOCK);
 		if (lm.locked()) {
@@ -554,26 +580,28 @@ AudioTrack::roll (nframes_t nframes, nframes_t start_frame, nframes_t end_frame,
 	}
 
 	if (!_active) {
-		silence (nframes, offset);
+		silence (nframes);
 		return 0;
 	}
 
 	transport_frame = _session.transport_frame();
 
-	if ((nframes = check_initial_delay (nframes, offset, transport_frame)) == 0) {
-		/* need to do this so that the diskstream sets its
-		   playback distance to zero, thus causing diskstream::commit
-		   to do nothing.
-		*/
-		return diskstream->process (transport_frame, 0, 0, can_record, rec_monitors_input);
-	} 
+	if (!can_record || !diskstream->record_enabled()) {
+		if ((nframes = check_initial_delay (nframes, transport_frame)) == 0) {
+			/* need to do this so that the diskstream sets its
+			   playback distance to zero, thus causing diskstream::commit
+			   to do nothing.
+			*/
+			return diskstream->process (transport_frame, 0, can_record, rec_monitors_input);
+		} 
+	}
 
 	_silent = false;
 	apply_gain_automation = false;
 
-	if ((dret = diskstream->process (transport_frame, nframes, offset, can_record, rec_monitors_input)) != 0) {
+	if ((dret = diskstream->process (transport_frame, nframes, can_record, rec_monitors_input)) != 0) {
 		
-		silence (nframes, offset);
+		silence (nframes);
 
 		return dret;
 	}
@@ -581,7 +609,7 @@ AudioTrack::roll (nframes_t nframes, nframes_t start_frame, nframes_t end_frame,
 	/* special condition applies */
 	
 	if (_meter_point == MeterInput) {
-		just_meter_input (start_frame, end_frame, nframes, offset);
+		just_meter_input (start_frame, end_frame, nframes);
 	}
 
 	if (diskstream->record_enabled() && !can_record && !Config->get_auto_input()) {
@@ -590,7 +618,7 @@ AudioTrack::roll (nframes_t nframes, nframes_t start_frame, nframes_t end_frame,
 		   at least potentially (depending on monitoring options)
 		 */
 
-		passthru (start_frame, end_frame, nframes, offset, 0, true);
+		passthru (start_frame, end_frame, nframes, 0, true);
 
 	} else if ((b = diskstream->playback_buffer(0)) != 0) {
 
@@ -684,18 +712,18 @@ AudioTrack::roll (nframes_t nframes, nframes_t start_frame, nframes_t end_frame,
 			}
 		}
 
-		process_output_buffers (bufs, limit, start_frame, end_frame, nframes, offset, (!_session.get_record_enabled() || !Config->get_do_not_record_plugins()), declick, (_meter_point != MeterInput));
+		process_output_buffers (bufs, limit, start_frame, end_frame, nframes, (!_session.get_record_enabled() || !Config->get_do_not_record_plugins()), declick, (_meter_point != MeterInput));
 		
 	} else {
 		/* problem with the diskstream; just be quiet for a bit */
-		silence (nframes, offset);
+		silence (nframes);
 	}
 
 	return 0;
 }
 
 int
-AudioTrack::silent_roll (nframes_t nframes, nframes_t start_frame, nframes_t end_frame, nframes_t offset, 
+AudioTrack::silent_roll (nframes_t nframes, nframes_t start_frame, nframes_t end_frame, 
 			 bool can_record, bool rec_monitors_input)
 {
 	if (n_outputs() == 0 && _redirects.empty()) {
@@ -703,20 +731,20 @@ AudioTrack::silent_roll (nframes_t nframes, nframes_t start_frame, nframes_t end
 	}
 
 	if (!_active) {
-		silence (nframes, offset);
+		silence (nframes);
 		return 0;
 	}
 
 	_silent = true;
 	apply_gain_automation = false;
 
-	silence (nframes, offset);
+	silence (nframes);
 
-	return audio_diskstream()->process (_session.transport_frame() + offset, nframes, offset, can_record, rec_monitors_input);
+	return audio_diskstream()->process (_session.transport_frame(), nframes, can_record, rec_monitors_input);
 }
 
 int
-AudioTrack::export_stuff (vector<Sample*>& buffers, uint32_t nbufs, nframes_t start, nframes_t nframes)
+AudioTrack::export_stuff (vector<Sample*>& buffers, uint32_t nbufs, nframes_t start, nframes_t nframes, bool enable_processing)
 {
 	gain_t  gain_automation[nframes];
 	gain_t  gain_buffer[nframes];
@@ -754,6 +782,9 @@ AudioTrack::export_stuff (vector<Sample*>& buffers, uint32_t nbufs, nframes_t st
 		}
 	}
 
+	// If no processing is required, there's no need to go any further.
+	if (!enable_processing)
+		return 0;
 
 	/* note: only run inserts during export. other layers in the machinery
 	   will already have checked that there are no external port inserts.
@@ -765,7 +796,7 @@ AudioTrack::export_stuff (vector<Sample*>& buffers, uint32_t nbufs, nframes_t st
 		if ((insert = boost::dynamic_pointer_cast<Insert>(*i)) != 0) {
 			switch (insert->placement()) {
 			case PreFader:
-				insert->run (buffers, nbufs, nframes, 0);
+				insert->run (buffers, nbufs, nframes);
 				break;
 			case PostFader:
 				post_fader_work = true;
@@ -788,10 +819,7 @@ AudioTrack::export_stuff (vector<Sample*>& buffers, uint32_t nbufs, nframes_t st
 	} else {
 
 		for (bi = buffers.begin(); bi != buffers.end(); ++bi) {
-			Sample *b = *bi;
-			for (nframes_t n = 0; n < nframes; ++n) {
-				b[n] *= this_gain;
-			}
+			apply_gain_to_buffer(*bi, nframes, this_gain);
 		}
 	}
 
@@ -805,7 +833,7 @@ AudioTrack::export_stuff (vector<Sample*>& buffers, uint32_t nbufs, nframes_t st
 				case PreFader:
 					break;
 				case PostFader:
-					insert->run (buffers, nbufs, nframes, 0);
+					insert->run (buffers, nbufs, nframes);
 					break;
 				}
 			}
@@ -825,10 +853,10 @@ AudioTrack::bounce (InterThreadInfo& itt)
 
 
 boost::shared_ptr<Region>
-AudioTrack::bounce_range (nframes_t start, nframes_t end, InterThreadInfo& itt)
+AudioTrack::bounce_range (nframes_t start, nframes_t end, InterThreadInfo& itt, bool enable_processing)
 {
 	vector<boost::shared_ptr<AudioSource> > srcs;
-	return _session.write_one_audio_track (*this, start, end, false, srcs, itt);
+	return _session.write_one_audio_track (*this, start, end, false, srcs, itt, enable_processing);
 }
 
 void
