@@ -29,12 +29,10 @@
 #include <ardour/audioengine.h>
 #include <ardour/buffer.h>
 #include <ardour/port.h>
+#include <ardour/io.h>
 #include <ardour/session.h>
 #include <ardour/cycle_timer.h>
 #include <ardour/utils.h>
-#ifdef VST_SUPPORT
-#include <fst.h>
-#endif
 
 #include <ardour/timestamps.h>
 
@@ -113,8 +111,10 @@ AudioEngine::start ()
 
 	if (!_running) {
 
+		nframes_t blocksize = jack_get_buffer_size (_jack);
+		Port::set_buffer_size (blocksize);
+
 		if (session) {
-			nframes_t blocksize = jack_get_buffer_size (_jack);
 
 			BootMessage (_("Connect session to engine"));
 
@@ -296,6 +296,14 @@ AudioEngine::process_callback (nframes_t nframes)
 		return 0;
 	}
 
+	/* reset port buffer offset for the start of a new cycle */
+
+	Port::set_port_offset (0);
+
+	/* tell all IO objects that we're starting a new cycle */
+
+	IO::CycleStart (nframes);
+
 	if (_freewheeling) {
 		if (Freewheel (nframes)) {
 			jack_set_freewheel (_jack, false);
@@ -343,7 +351,7 @@ AudioEngine::process_callback (nframes_t nframes)
 			Port *port = (*i);
 			
 			if (port->sends_output()) {
-				Sample *buf = port->get_buffer(nframes);
+				Sample *buf = port->get_buffer (nframes);
 				memset (buf, 0, sizeof(Sample) * nframes);
 				// this should work but doesn't
 				//port->silence(0, nframes);  //need to implement declicking fade
@@ -394,8 +402,11 @@ AudioEngine::jack_bufsize_callback (nframes_t nframes)
 	_usecs_per_cycle = (int) floor ((((double) nframes / frame_rate())) * 1000000.0);
 	last_monitor_check = 0;
 
-	boost::shared_ptr<Ports> p = ports.reader();
+	cerr << "bufsize: Set Port buffer size to " << nframes << endl;
+	Port::set_buffer_size (nframes);
 
+	boost::shared_ptr<Ports> p = ports.reader();
+	
 	for (Ports::iterator i = p->begin(); i != p->end(); ++i) {
 		(*i)->reset();
 	}
@@ -453,7 +464,7 @@ AudioEngine::set_session (Session *s)
 		/* page in as much of the session process code as we
 		   can before we really start running.
 		*/
-		
+
 		session->process (blocksize);
 		session->process (blocksize);
 		session->process (blocksize);
@@ -496,9 +507,9 @@ AudioEngine::port_registration_failure (const std::string& portname)
 	string reason;
 	
 	if (p) {
-		reason = _("a port with this name already exists: check for duplicated track/bus names");
+		reason = string_compose (_("a port with the name \"%1\" already exists: check for duplicated track/bus names"), portname);
 	} else {
-		reason = _("unknown error");
+		reason = _("No more JACK ports are available. You will need to stop Ardour and restart JACK with ports if you need this many tracks.");
 	}
 	
 	throw PortRegistrationFailure (string_compose (_("AudioEngine: cannot register port \"%1\": %2"), portname, reason).c_str());
@@ -807,6 +818,7 @@ AudioEngine::halted (void *arg)
 	ae->_running = false;
 	ae->_buffer_size = 0;
 	ae->_frame_rate = 0;
+	ae->_jack = 0;
 
 	if (was_running) {
 		ae->Halted(); /* EMIT SIGNAL */
@@ -950,8 +962,7 @@ nframes_t
 AudioEngine::get_port_total_latency (const Port& port)
 {
 	if (!_jack) {
-		fatal << _("get_port_total_latency() called with no JACK client connection") << endmsg;
-		/*NOTREACHED*/
+		return 0;
 	}
 
 	return jack_port_get_total_latency (_jack, port._port);
@@ -1176,7 +1187,7 @@ AudioEngine::reconnect_to_jack ()
 		(*i)->reset ();
 
 		if ((*i)->flags() & JackPortIsOutput) {
-			(*i)->silence (jack_get_buffer_size (_jack), 0);
+			(*i)->silence (jack_get_buffer_size (_jack));
 		}
 	}
 
@@ -1192,6 +1203,7 @@ AudioEngine::reconnect_to_jack ()
 	if (session) {
 		session->reset_jack_connection (_jack);
 		nframes_t blocksize = jack_get_buffer_size (_jack);
+		Port::set_buffer_size (blocksize);
 		session->set_block_size (blocksize);
 		session->set_frame_rate (jack_get_sample_rate (_jack));
 	}
