@@ -100,6 +100,7 @@ Crossfade::Crossfade (boost::shared_ptr<AudioRegion> a, boost::shared_ptr<AudioR
 {
 	_in_update = false;
 	_fixed = false;
+	_follow_overlap = false;
 
 	if (compute (a, b, model)) {
 		throw failed_constructor();
@@ -162,6 +163,12 @@ Crossfade::Crossfade (const Playlist& playlist, XMLNode& node)
 	if (set_state (node)) {
 		throw failed_constructor();
 	}
+
+	/* we should not need to do this here, since all values were set via XML. however
+	   some older sessions may have bugs and this allows us to fix them.
+	*/
+	
+	update ();
 }
 
 Crossfade::Crossfade (const Crossfade &orig, boost::shared_ptr<AudioRegion> newin, boost::shared_ptr<AudioRegion> newout)
@@ -468,11 +475,11 @@ Crossfade::update ()
 		break;
 		
 	case EndOfIn:
-		_position = _in->last_frame() - _length;
+		_position = _in->last_frame() - _length + 1;
 		break;
 		
 	case EndOfOut:
-		_position = _out->last_frame() - _length;
+		_position = _out->last_frame() - _length + 1;
 	}
 
 	return true;
