@@ -45,6 +45,8 @@
 
 #include <cmath>
 
+#include <cstdlib>
+
 /*
   A bug in OS X's cmath that causes isnan() and isinf() to be 
   "undeclared". the following works around that
@@ -72,6 +74,7 @@ sigc::signal<int>                 IO::PortsLegal;
 sigc::signal<int>                 IO::PannersLegal;
 sigc::signal<void,uint32_t>  IO::MoreOutputs;
 sigc::signal<int>                 IO::PortsCreated;
+sigc::signal<void,nframes_t>      IO::CycleStart;
 
 Glib::StaticMutex       IO::m_meter_signal_lock = GLIBMM_STATIC_MUTEX_INIT;
 
@@ -92,9 +95,37 @@ static double direct_gain_to_control (gain_t gain) {
 	return pow((6.0*log(gain)/log(2.0)+192.0)/198.0, 8.0);
 }
 
-static bool sort_ports_by_name (Port* a, Port* b)
-{
-	return a->name() < b->name();
+static bool sort_ports_by_name (Port* a, Port* b) {
+
+	unsigned int	last_digit_position_a = a->name().size();
+	std::string::reverse_iterator	r_iterator = a->name().rbegin();
+
+	while (r_iterator!=a->name().rend() and Glib::Unicode::isdigit(*r_iterator)) {
+		r_iterator++; last_digit_position_a--;
+	}
+
+	unsigned int	last_digit_position_b = b->name().size();
+	r_iterator = b->name().rbegin();
+
+	while (r_iterator!=b->name().rend() and Glib::Unicode::isdigit(*r_iterator)) {
+		r_iterator++; last_digit_position_b--;
+	}
+
+	// if some of the names don't have a number as posfix, compare as strings
+	if (last_digit_position_a == a->name().size() or last_digit_position_b == b->name().size()) {
+		return a->name() < b->name();
+	}
+
+	const std::string 	prefix_a = a->name().substr(0, last_digit_position_a - 1);
+	const unsigned int 	posfix_a = std::atoi(a->name().substr(last_digit_position_a, a->name().size() - last_digit_position_a).c_str());
+	const std::string 	prefix_b = b->name().substr(0, last_digit_position_b - 1);
+	const unsigned int 	posfix_b = std::atoi(b->name().substr(last_digit_position_b, b->name().size() - last_digit_position_b).c_str());
+
+	if (prefix_a != prefix_b) {
+		return a->name() < b->name();
+	} else {
+		return posfix_a < posfix_b;
+	}
 }
 
 
@@ -141,6 +172,9 @@ IO::IO (Session& s, string name,
 		m_meter_connection = Meter.connect (mem_fun (*this, &IO::meter));
 	}
 
+	_output_offset = 0;
+	CycleStart.connect (mem_fun (*this, &IO::cycle_start));
+
 	_session.add_controllable (&_gain_control);
 }
 
@@ -173,6 +207,9 @@ IO::IO (Session& s, const XMLNode& node, DataType dt)
 		m_meter_connection = Meter.connect (mem_fun (*this, &IO::meter));
 	}
 
+	_output_offset = 0;
+	CycleStart.connect (mem_fun (*this, &IO::cycle_start));
+
 	_session.add_controllable (&_gain_control);
 }
 
@@ -199,12 +236,12 @@ IO::~IO ()
 }
 
 void
-IO::silence (nframes_t nframes, nframes_t offset)
+IO::silence (nframes_t nframes)
 {
 	/* io_lock, not taken: function must be called from Session::process() calltree */
 
 	for (vector<Port *>::iterator i = _outputs.begin(); i != _outputs.end(); ++i) {
-		(*i)->silence (nframes, offset);
+		(*i)->silence (nframes);
 	}
 }
 
@@ -265,7 +302,7 @@ IO::apply_declick (vector<Sample *>& bufs, uint32_t nbufs, nframes_t nframes, ga
 }
 
 void
-IO::pan_automated (vector<Sample*>& bufs, uint32_t nbufs, nframes_t start, nframes_t end, nframes_t nframes, nframes_t offset)
+IO::pan_automated (vector<Sample*>& bufs, uint32_t nbufs, nframes_t start, nframes_t end, nframes_t nframes)
 {
 	Sample* dst;
 
@@ -277,7 +314,7 @@ IO::pan_automated (vector<Sample*>& bufs, uint32_t nbufs, nframes_t start, nfram
 
 	if (_noutputs == 1) {
 
-		dst = output(0)->get_buffer (nframes) + offset;
+		dst = get_output_buffer (0, nframes);
 
 		for (uint32_t n = 0; n < nbufs; ++n) {
 			if (bufs[n] != dst) {
@@ -299,7 +336,7 @@ IO::pan_automated (vector<Sample*>& bufs, uint32_t nbufs, nframes_t start, nfram
 	/* the terrible silence ... */
 
 	for (out = _outputs.begin(), o = 0; out != _outputs.end(); ++out, ++o) {
-		obufs[o] = (*out)->get_buffer (nframes) + offset;
+		obufs[o] = get_output_buffer (o, nframes);
 		memset (obufs[o], 0, sizeof (Sample) * nframes);
 		(*out)->mark_silence (false);
 	}
@@ -312,7 +349,7 @@ IO::pan_automated (vector<Sample*>& bufs, uint32_t nbufs, nframes_t start, nfram
 }
 
 void
-IO::pan (vector<Sample*>& bufs, uint32_t nbufs, nframes_t nframes, nframes_t offset, gain_t gain_coeff)
+IO::pan (vector<Sample*>& bufs, uint32_t nbufs, nframes_t nframes, gain_t gain_coeff)
 {
 	Sample* dst;
 	Sample* src;
@@ -328,13 +365,13 @@ IO::pan (vector<Sample*>& bufs, uint32_t nbufs, nframes_t nframes, nframes_t off
 	*/
 
 	if (_panner->bypassed() || _panner->empty()) {
-		deliver_output_no_pan (bufs, nbufs, nframes, offset);
+		deliver_output_no_pan (bufs, nbufs, nframes);
 		return;
 	}
 
 	if (_noutputs == 1) {
 
-		dst = output(0)->get_buffer (nframes) + offset;
+		dst = get_output_buffer (0, nframes);
 
 		if (gain_coeff == 0.0f) {
 
@@ -389,7 +426,7 @@ IO::pan (vector<Sample*>& bufs, uint32_t nbufs, nframes_t nframes, nframes_t off
 	/* XXX this is wasteful but i see no way to avoid it */
 	
 	for (out = _outputs.begin(), o = 0; out != _outputs.end(); ++out, ++o) {
-		obufs[o] = (*out)->get_buffer (nframes) + offset;
+		obufs[o] = get_output_buffer (o, nframes);
 		memset (obufs[o], 0, sizeof (Sample) * nframes);
 		(*out)->mark_silence (false);
 	}
@@ -411,7 +448,7 @@ IO::pan (vector<Sample*>& bufs, uint32_t nbufs, nframes_t nframes, nframes_t off
 }
 
 void
-IO::deliver_output (vector<Sample *>& bufs, uint32_t nbufs, nframes_t nframes, nframes_t offset)
+IO::deliver_output (vector<Sample *>& bufs, uint32_t nbufs, nframes_t nframes)
 {
 	/* io_lock, not taken: function must be called from Session::process() calltree */
 
@@ -420,7 +457,7 @@ IO::deliver_output (vector<Sample *>& bufs, uint32_t nbufs, nframes_t nframes, n
 	}
 	
 	if (_panner->bypassed() || _panner->empty()) {
-		deliver_output_no_pan (bufs, nbufs, nframes, offset);
+		deliver_output_no_pan (bufs, nbufs, nframes);
 		return;
 	}
 
@@ -447,14 +484,14 @@ IO::deliver_output (vector<Sample *>& bufs, uint32_t nbufs, nframes_t nframes, n
 	/* simple, non-automation panning to outputs */
 
 	if (_session.transport_speed() > 1.5f || _session.transport_speed() < -1.5f) {
-		pan (bufs, nbufs, nframes, offset, pangain * speed_quietning);
+		pan (bufs, nbufs, nframes, pangain * speed_quietning);
 	} else {
-		pan (bufs, nbufs, nframes, offset, pangain);
+		pan (bufs, nbufs, nframes, pangain);
 	}
 }
 
 void
-IO::deliver_output_no_pan (vector<Sample *>& bufs, uint32_t nbufs, nframes_t nframes, nframes_t offset)
+IO::deliver_output_no_pan (vector<Sample *>& bufs, uint32_t nbufs, nframes_t nframes)
 {
 	/* io_lock, not taken: function must be called from Session::process() calltree */
 
@@ -504,7 +541,7 @@ IO::deliver_output_no_pan (vector<Sample *>& bufs, uint32_t nbufs, nframes_t nfr
 	
 	for (o = _outputs.begin(), i = 0; o != _outputs.end(); ++o, ++i) {
 
-		dst = (*o)->get_buffer (nframes) + offset;
+		dst = get_output_buffer (i, nframes);
 		src = bufs[min(nbufs,i)];
 
 		if (dg != _gain) {
@@ -536,7 +573,7 @@ IO::deliver_output_no_pan (vector<Sample *>& bufs, uint32_t nbufs, nframes_t nfr
 }
 
 void
-IO::collect_input (vector<Sample *>& bufs, uint32_t nbufs, nframes_t nframes, nframes_t offset)
+IO::collect_input (vector<Sample *>& bufs, uint32_t nbufs, nframes_t nframes)
 {
 	/* io_lock, not taken: function must be called from Session::process() calltree */
 
@@ -550,19 +587,8 @@ IO::collect_input (vector<Sample *>& bufs, uint32_t nbufs, nframes_t nframes, nf
 		if (i == _inputs.end()) {
 			break;
 		}
-		
-		/* XXX always read the full extent of the port buffer that
-		   we need. One day, we may use jack_port_get_buffer_at_offset()
-		   or something similar. For now, this simple hack will
-		   have to do.
 
-		   Hack? Why yes .. we only need to read nframes-worth of
-		   data, but the data we want is at `offset' within the
-		   buffer.
-		*/
-
-		last = (*i)->get_buffer (nframes+offset) + offset;
-		// the dest buffer's offset has already been applied
+		last = get_input_buffer (n, nframes);
 		memcpy (bufs[n], last, sizeof (Sample) * nframes);
 	}
 
@@ -570,7 +596,6 @@ IO::collect_input (vector<Sample *>& bufs, uint32_t nbufs, nframes_t nframes, nf
 	
 	if (last) {
 		while (n < nbufs) {
-			// the dest buffer's offset has already been applied
 			memcpy (bufs[n], last, sizeof (Sample) * nframes);
 			++n;
 		}
@@ -583,13 +608,12 @@ IO::collect_input (vector<Sample *>& bufs, uint32_t nbufs, nframes_t nframes, nf
 }
 
 void
-IO::just_meter_input (nframes_t start_frame, nframes_t end_frame, 
-		      nframes_t nframes, nframes_t offset)
+IO::just_meter_input (nframes_t start_frame, nframes_t end_frame, nframes_t nframes)
 {
 	vector<Sample*>& bufs = _session.get_passthru_buffers ();
 	uint32_t nbufs = n_process_buffers ();
 
-	collect_input (bufs, nbufs, nframes, offset);
+	collect_input (bufs, nbufs, nframes);
 
 	for (uint32_t n = 0; n < nbufs; ++n) {
 		_peak_power[n] = Session::compute_peak (bufs[n], nframes, _peak_power[n]);
@@ -2560,8 +2584,11 @@ IO::set_gain_automation_state (AutoState state)
 			changed = true;
 			last_automation_snapshot = 0;
 			_gain_automation_curve.set_automation_state (state);
-			
-			if (state != Off) {
+
+			/* don't reset gain if we're moving to Off or Write mode;
+			   if we're moving to Write, the user may have manually set up gains
+			   that they don't want to lose */
+			if (state != Off && state != Write) {
 				set_gain (_gain_automation_curve.eval (_session.transport_frame()), this);
 			}
 		}
@@ -2806,4 +2833,61 @@ IO::set_active (bool yn)
 	 active_changed(); /* EMIT SIGNAL */
 }
 
+string
+IO::name_from_state (const XMLNode& node)
+{
+	const XMLProperty* prop;
+	
+	if ((prop = node.property ("name")) != 0) {
+		return prop->value();
+	} 
+	
+	return string();
+}
 
+void
+IO::set_name_in_state (XMLNode& node, const string& new_name)
+{
+	const XMLProperty* prop;
+	
+	if ((prop = node.property ("name")) != 0) {
+		node.add_property ("name", new_name);
+	} 
+}
+
+void
+IO::cycle_start (nframes_t nframes)
+{
+	_output_offset = 0;
+}
+
+void
+IO::increment_output_offset (nframes_t n)
+{
+	_output_offset += n;
+}
+
+Sample*
+IO::get_input_buffer (int n, nframes_t nframes)
+{
+	Port* port;
+
+	if (!(port = input (n))) {
+		return 0;
+	}
+
+	return port->get_buffer (nframes);
+}
+
+Sample*
+IO::get_output_buffer (int n, nframes_t nframes)
+{
+	Port* port;
+
+	if (!(port = output (n))) {
+		return 0;
+	}
+
+	return port->get_buffer (nframes) + _output_offset;
+}
+	       
