@@ -360,7 +360,23 @@ PluginManager::ladspa_discover (string path)
 			}
 		}
 
-		_ladspa_plugin_info.push_back (info);
+		if(_ladspa_plugin_info.empty()){
+			_ladspa_plugin_info.push_back (info);
+		}
+
+		//Ensure that the plugin is not already in the plugin list.
+
+		bool found = false;
+
+		for (PluginInfoList::const_iterator i = _ladspa_plugin_info.begin(); i != _ladspa_plugin_info.end(); ++i) {
+			if(0 == info->unique_id.compare((*i)->unique_id)){
+			      found = true;
+			}
+		}
+
+		if(!found){
+		    _ladspa_plugin_info.push_back (info);
+		}
 	}
 
 // GDB WILL NOT LIKE YOU IF YOU DO THIS
@@ -482,6 +498,7 @@ PluginManager::vst_discover_from_path (string path)
 
 	if (plugin_objects) {
 		for (x = plugin_objects->begin(); x != plugin_objects->end (); ++x) {
+			std::cerr << " discovering " << **x << std::endl;
 			vst_discover (**x);
 		}
 	}
@@ -522,7 +539,7 @@ PluginManager::vst_discover (string path)
 	info->unique_id = buf;
 	info->category = "VST";
 	info->path = path;
-	// need to set info->creator but FST doesn't provide it
+	info->creator = finfo->creator;
 	info->index = 0;
 	info->n_inputs = finfo->numInputs;
 	info->n_outputs = finfo->numOutputs;
