@@ -1155,7 +1155,7 @@ Session::midi_thread_work ()
 	bool restart;
 	vector<MIDI::Port*> ports;
 
-	PBD::ThreadCreatedWithRequestSize (pthread_self(), X_("MIDI"), 2048);
+	PBD::notify_gui_about_thread_creation (pthread_self(), X_("MIDI"), 2048);
 
 	memset (&rtparam, 0, sizeof (rtparam));
 	rtparam.sched_priority = 9; /* XXX should be relative to audio (JACK) thread */
@@ -1187,6 +1187,7 @@ Session::midi_thread_work ()
 			pfd[nfds].fd = _mmc_port->selectable();
 			pfd[nfds].events = POLLIN|POLLHUP|POLLERR;
 			ports[nfds] = _mmc_port;
+			//cerr << "MIDI port " << nfds << " = MMC @ " << _mmc_port << endl;
 			nfds++;
 		}
 
@@ -1199,6 +1200,7 @@ Session::midi_thread_work ()
 			pfd[nfds].fd = _mtc_port->selectable();
 			pfd[nfds].events = POLLIN|POLLHUP|POLLERR;
 			ports[nfds] = _mtc_port;
+			//cerr << "MIDI port " << nfds << " = MTC @ " << _mtc_port << endl;
 			nfds++;
 		}
 
@@ -1206,6 +1208,7 @@ Session::midi_thread_work ()
 			pfd[nfds].fd = _midi_port->selectable();
 			pfd[nfds].events = POLLIN|POLLHUP|POLLERR;
 			ports[nfds] = _midi_port;
+			// cerr << "MIDI port " << nfds << " = MIDI @ " << _midi_port << endl;
 			nfds++;
 		}
 		
