@@ -1359,6 +1359,13 @@ Session::load_routes (const XMLNode& node)
 	set_dirty();
 
 	for (niter = nlist.begin(); niter != nlist.end(); ++niter) {
+		XMLProperty* prop = (*niter)->property ("default-type");
+		
+		if (prop && prop->value() == "unknown" ) {
+			std::cout << "ignoring route with type unknown. (video-track)" << std::endl;
+			// Note: this may mess up remote_control IDs or more..
+			continue;
+		}
 
 		boost::shared_ptr<Route> route (XMLRouteFactory (**niter));
 
@@ -2057,6 +2064,12 @@ Session::template_dir ()
 	return Glib::build_filename (get_user_ardour_path(), "templates");
 }
 
+string
+Session::route_template_dir ()
+{
+	return Glib::build_filename (get_user_ardour_path(), "route_templates");
+}
+
 string
 Session::export_dir () const
 {
@@ -2103,6 +2116,13 @@ Session::template_path ()
 	return suffixed_search_path (X_("templates"), true);
 }
 
+
+string
+Session::route_template_path ()
+{
+	return suffixed_search_path (X_("route_templates"), true);
+}
+
 string
 Session::control_protocol_path ()
 {
@@ -2471,6 +2491,43 @@ Session::get_template_list (list<string> &template_names)
 	}
 }
 
+void
+Session::get_route_templates (vector<RouteTemplateInfo>& template_names)
+{
+	vector<string *> *templates;
+	PathScanner scanner;
+	string path;
+
+	path = route_template_path ();
+	
+	templates = scanner (path, template_filter, 0, false, true);
+	
+	if (!templates) {
+	  return;
+	}
+
+	for (vector<string*>::iterator i = templates->begin(); i != templates->end(); ++i) {
+		string fullpath = *(*i);
+
+		XMLTree tree;
+
+		if (!tree.read (fullpath.c_str())) {
+		  continue;
+		}
+
+		XMLNode* root = tree.root();
+		
+		RouteTemplateInfo rti;
+
+		rti.name = IO::name_from_state (*root->children().front());
+		rti.path = fullpath;
+
+		template_names.push_back (rti);
+	}
+
+	free (templates);
+}
+
 int
 Session::read_favorite_dirs (FavoriteDirs & favs)
 {
@@ -2569,12 +2626,17 @@ Session::find_all_sources (string path, set<string>& result)
 			continue;
 		}
 
-		string path = _path; /* /-terminated */
-		path += sound_dir_name;
-		path += '/';
-		path += prop->value();
+		/* now we have to actually find the file */
 
-		result.insert (path);
+		bool is_new;
+		uint16_t chan;
+		Glib::ustring path;
+		std::string name;
+		
+		if (AudioFileSource::find (prop->value(), true, false, is_new, chan, path, name)) {
+			cerr << "Got " << path << " from XML source with prop = " << prop->value() << endl;
+			result.insert (path);
+		}
 	}
 
 	return 0;
@@ -2762,6 +2824,8 @@ Session::cleanup_sources (Session::cleanup_report& rep)
 			realpath(spath.c_str(), tmppath1);
 			realpath((*i).c_str(),  tmppath2);
 
+			cerr << "comparing " << tmppath1 << " and " << tmppath2 << endl;
+
 			if (strcmp(tmppath1, tmppath2) == 0) {
 				used = true;
 				break;
