@@ -20,6 +20,7 @@
 #include <cstring>
 #include <cerrno>
 #include <climits>
+#include <cstdarg>
 
 #include <pwd.h>
 #include <sys/utsname.h>
@@ -31,6 +32,7 @@
 #include <ardour/sndfilesource.h>
 #include <ardour/sndfile_helpers.h>
 #include <ardour/utils.h>
+#include <ardour/version.h>
 
 #include "i18n.h"
 
@@ -46,6 +48,22 @@ const AudioFileSource::Flag SndFileSource::default_writable_flags = AudioFileSou
 											   AudioFileSource::Removable|
 											   AudioFileSource::RemovableIfEmpty|
 											   AudioFileSource::CanRename);
+
+static void
+snprintf_bounded_null_filled (char* target, size_t target_size, const char* fmt, ...)
+{
+	char buf[target_size+1];
+	va_list ap;
+
+	va_start (ap, fmt);
+	vsnprintf (buf, target_size+1, fmt, ap);
+	va_end (ap);
+
+	memset (target, 0, target_size);
+	memcpy (target, buf, target_size);
+
+}
+
 SndFileSource::SndFileSource (Session& s, const XMLNode& node)
 	: AudioFileSource (s, node)
 {
@@ -139,24 +157,17 @@ SndFileSource::SndFileSource (Session& s, ustring path, SampleFormat sfmt, Heade
 
 	if (writable() && (_flags & Broadcast)) {
 
-		_broadcast_info = new SF_BROADCAST_INFO;
-		memset (_broadcast_info, 0, sizeof (*_broadcast_info));
-		
-		snprintf (_broadcast_info->description, sizeof (_broadcast_info->description), "BWF %s", _name.c_str());
-		
-		struct utsname utsinfo;
-
-		if (uname (&utsinfo)) {
-			error << string_compose(_("FileSource: cannot get host information for BWF header (%1)"), strerror(errno)) << endmsg;
-			return;
+		if (!_broadcast_info) {
+			_broadcast_info = new SF_BROADCAST_INFO;
+			memset (_broadcast_info, 0, sizeof (*_broadcast_info));
 		}
 		
-		snprintf (_broadcast_info->originator, sizeof (_broadcast_info->originator), "ardour:%s:%s:%s:%s:%s)", 
-			  Glib::get_real_name().c_str(),
-			  utsinfo.nodename,
-			  utsinfo.sysname,
-			  utsinfo.release,
-			  utsinfo.version);
+		snprintf_bounded_null_filled (_broadcast_info->description, sizeof (_broadcast_info->description), "BWF %s", _name.c_str());
+		snprintf_bounded_null_filled (_broadcast_info->originator, sizeof (_broadcast_info->originator), "ardour %d.%d.%d %s", 
+					      libardour2_major_version,
+					      libardour2_minor_version,
+					      libardour2_micro_version,
+					      Glib::get_real_name().c_str());
 		
 		_broadcast_info->version = 1;  
 		_broadcast_info->time_reference_low = 0;  
@@ -164,7 +175,7 @@ SndFileSource::SndFileSource (Session& s, ustring path, SampleFormat sfmt, Heade
 		
 		/* XXX do something about this field */
 		
-		snprintf (_broadcast_info->umid, sizeof (_broadcast_info->umid), "%s", "fnord");
+		snprintf_bounded_null_filled (_broadcast_info->umid, sizeof (_broadcast_info->umid), "%s", "fnord");
 		
 		/* coding history is added by libsndfile */
 
@@ -241,8 +252,10 @@ SndFileSource::open ()
 
 	_length = _info.frames;
 
-	_broadcast_info = new SF_BROADCAST_INFO;
-	memset (_broadcast_info, 0, sizeof (*_broadcast_info));
+	if (!_broadcast_info) {
+		_broadcast_info = new SF_BROADCAST_INFO;
+		memset (_broadcast_info, 0, sizeof (*_broadcast_info));
+	}
 	
 	bool timecode_info_exists;
 
@@ -336,7 +349,12 @@ SndFileSource::read_unlocked (Sample *dst, nframes_t start, nframes_t cnt) const
 		
 		if (_info.channels == 1) {
 			nframes_t ret = sf_read_float (sf, dst, file_cnt);
-			_read_data_count = cnt * sizeof(float);
+			_read_data_count = ret * sizeof(float);
+			if (ret != file_cnt) {
+				char errbuf[256];
+				sf_error_str (0, errbuf, sizeof (errbuf) - 1);
+				cerr << string_compose(_("SndFileSource: @ %1 could not read %2 within %3 (%4) (len = %5)"), start, file_cnt, _name.substr (1), errbuf, _length) << endl;
+			}
 			return ret;
 		}
 	}
@@ -400,7 +418,7 @@ SndFileSource::nondestructive_write_unlocked (Sample *data, nframes_t cnt)
 	}
 
 	_write_data_count = cnt;
-	
+
 	return cnt;
 }
 
@@ -536,25 +554,25 @@ SndFileSource::setup_broadcast_info (nframes_t when, struct tm& now, time_t tnow
 	
 	int random_code = random() % 999999999;
 	
-	snprintf (_broadcast_info->originator_reference, sizeof (_broadcast_info->originator_reference), "%2s%3s%12s%02d%02d%02d%9d",
-		  Config->get_bwf_country_code().c_str(),
-		  Config->get_bwf_organization_code().c_str(),
-		  bwf_serial_number,
-		  now.tm_hour,
-		  now.tm_min,
-		  now.tm_sec,
-		  random_code);
+	snprintf_bounded_null_filled (_broadcast_info->originator_reference, sizeof (_broadcast_info->originator_reference), "%2s%3s%12s%02d%02d%02d%9d",
+				      Config->get_bwf_country_code().c_str(),
+				      Config->get_bwf_organization_code().c_str(),
+				      bwf_serial_number,
+				      now.tm_hour,
+				      now.tm_min,
+				      now.tm_sec,
+				      random_code);
 	
-	snprintf (_broadcast_info->origination_date, sizeof (_broadcast_info->origination_date), "%4d-%02d-%02d",
-		  1900 + now.tm_year,
-		  now.tm_mon,
-		  now.tm_mday);
+	snprintf_bounded_null_filled (_broadcast_info->origination_date, sizeof (_broadcast_info->origination_date), "%4d-%02d-%02d",
+				      1900 + now.tm_year,
+				      now.tm_mon + 1, // shift range from 0..11 to 1..12
+				      now.tm_mday);
+	
+	snprintf_bounded_null_filled (_broadcast_info->origination_time, sizeof (_broadcast_info->origination_time), "%02d:%02d:%02d",
+				      now.tm_hour,
+				      now.tm_min,
+				      now.tm_sec);
 	
-	snprintf (_broadcast_info->origination_time, sizeof (_broadcast_info->origination_time), "%02d:%02d:%02d",
-		  now.tm_hour,
-		  now.tm_min,
-		  now.tm_sec);
-
 	/* now update header position taking header offset into account */
 	
 	set_header_timeline_position ();
