@@ -207,7 +207,7 @@ Track::set_name (string str, void *src)
 
 	/* save state so that the statefile fully reflects any filename changes */
 
-	if ((ret = IO::set_name (str, src)) == 0) {
+	if ((ret = Route::set_name (str, src)) == 0) {
 		_session.save_state ("");
 	}
 	return ret;
@@ -220,3 +220,10 @@ Track::set_latency_delay (nframes_t longest_session_latency)
 	_diskstream->set_roll_delay (_roll_delay);
 }
 
+void
+Track::zero_diskstream_id_in_xml (XMLNode& node)
+{
+	if (node.property ("diskstream-id")) {
+		node.add_property ("diskstream-id", "0");
+	}
+}
