@@ -41,8 +41,7 @@ bool MackieControlProtocol::probe()
 
 void * MackieControlProtocol::monitor_work()
 {
-	// What does ThreadCreatedWithRequestSize do?
-	PBD::ThreadCreated (pthread_self(), X_("Mackie"));
+	PBD::notify_gui_about_thread_creation (pthread_self(), X_("Mackie"));
 
 	pthread_setcancelstate (PTHREAD_CANCEL_ENABLE, 0);
 	pthread_setcanceltype (PTHREAD_CANCEL_ASYNCHRONOUS, 0);
@@ -61,8 +60,8 @@ void * MackieControlProtocol::monitor_work()
 					update_ports();
 				}
 			}
-			// poll for automation data from the routes
-			poll_automation();
+			// poll for session data that needs to go to the unit
+			poll_session_data();
 		}
 		catch ( exception & e )
 		{
@@ -94,15 +93,22 @@ void MackieControlProtocol::update_ports()
 		if ( _ports_changed )
 		{
 			// create new pollfd structures
-			if ( pfd != 0 ) delete[] pfd;
+			if ( pfd != 0 )
+			{
+				delete[] pfd;
+				pfd = 0;
+			}
 			pfd = new pollfd[_ports.size()];
+#ifdef DEBUG
+			cout << "pfd: " << pfd << endl;
+#endif
 			nfds = 0;
 			for( MackiePorts::iterator it = _ports.begin(); it != _ports.end(); ++it )
 			{
 				// add the port any handler
 				(*it)->connect_any();
 #ifdef DEBUG
-				cout << "adding pollfd for port " << (*it)->port().name() << " to pollfd" << endl;
+				cout << "adding pollfd for port " << (*it)->port().name() << " to pollfd " << nfds << endl;
 #endif
 				pfd[nfds].fd = (*it)->port().selectable();
 				pfd[nfds].events = POLLIN|POLLHUP|POLLERR;
@@ -129,7 +135,7 @@ void MackieControlProtocol::read_ports()
 		// this will cause handle_midi_any in the MackiePort to be triggered
 		// for alsa/raw ports
 		// alsa/sequencer ports trigger the midi parser off poll
-		if ( pfd[p].revents & POLLIN > 0 )
+		if ( (pfd[p].revents & POLLIN) > 0 )
 		{
 			// avoid deadlocking?
 			// doesn't seem to make a difference
